# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/resolved_ast.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/resolved_ast.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import annotation_pb2 as zetasql_dot_public_dot_annotation__pb2
from zetasql.wasi._pb2.zetasql.public.proto import type_annotation_pb2 as zetasql_dot_public_dot_proto_dot_type__annotation__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.public import type_modifiers_pb2 as zetasql_dot_public_dot_type__modifiers__pb2
from zetasql.wasi._pb2.zetasql.public import type_parameters_pb2 as zetasql_dot_public_dot_type__parameters__pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as zetasql_dot_proto_dot_function__pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import serialization_pb2 as zetasql_dot_resolved__ast_dot_serialization__pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_ast_enums_pb2 as zetasql_dot_resolved__ast_dot_resolved__ast__enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'zetasql/resolved_ast/resolved_ast.proto\x12\x07zetasql\x1a\x1fzetasql/public/annotation.proto\x1a*zetasql/public/proto/type_annotation.proto\x1a\x19zetasql/public/type.proto\x1a#zetasql/public/type_modifiers.proto\x1a$zetasql/public/type_parameters.proto\x1a\x1czetasql/proto/function.proto\x1a(zetasql/resolved_ast/serialization.proto\x1a-zetasql/resolved_ast/resolved_ast_enums.proto\"\xa4\x02\n\x14\x41nyResolvedNodeProto\x12\x43\n\x16resolved_argument_node\x18\x01 \x01(\x0b\x32!.zetasql.AnyResolvedArgumentProtoH\x00\x12;\n\x12resolved_expr_node\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProtoH\x00\x12;\n\x12resolved_scan_node\x18\x12 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProtoH\x00\x12\x45\n\x17resolved_statement_node\x18$ \x01(\x0b\x32\".zetasql.AnyResolvedStatementProtoH\x00\x42\x06\n\x04node\"\xd2\x35\n\x18\x41nyResolvedArgumentProto\x12N\n\x1eresolved_make_proto_field_node\x18\x0e \x01(\x0b\x32$.zetasql.ResolvedMakeProtoFieldProtoH\x00\x12I\n\x1bresolved_column_holder_node\x18\x17 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProtoH\x00\x12H\n\x1bresolved_order_by_item_node\x18! \x01(\x0b\x32!.zetasql.ResolvedOrderByItemProtoH\x00\x12I\n\x1bresolved_output_column_node\x18\" \x01(\x0b\x32\".zetasql.ResolvedOutputColumnProtoH\x00\x12\x43\n\x18resolved_with_entry_node\x18\x34 \x01(\x0b\x32\x1f.zetasql.ResolvedWithEntryProtoH\x00\x12<\n\x14resolved_option_node\x18\x35 \x01(\x0b\x32\x1c.zetasql.ResolvedOptionProtoH\x00\x12U\n!resolved_window_partitioning_node\x18\x36 \x01(\x0b\x32(.zetasql.ResolvedWindowPartitioningProtoH\x00\x12M\n\x1dresolved_window_ordering_node\x18\x37 \x01(\x0b\x32$.zetasql.ResolvedWindowOrderingProtoH\x00\x12G\n\x1aresolved_window_frame_node\x18\x38 \x01(\x0b\x32!.zetasql.ResolvedWindowFrameProtoH\x00\x12\\\n%resolved_analytic_function_group_node\x18\x39 \x01(\x0b\x32+.zetasql.ResolvedAnalyticFunctionGroupProtoH\x00\x12P\n\x1fresolved_window_frame_expr_node\x18: \x01(\x0b\x32%.zetasql.ResolvedWindowFrameExprProtoH\x00\x12@\n\x16resolved_dmlvalue_node\x18; \x01(\x0b\x32\x1e.zetasql.ResolvedDMLValueProtoH\x00\x12V\n\"resolved_assert_rows_modified_node\x18= \x01(\x0b\x32(.zetasql.ResolvedAssertRowsModifiedProtoH\x00\x12\x43\n\x18resolved_insert_row_node\x18> \x01(\x0b\x32\x1f.zetasql.ResolvedInsertRowProtoH\x00\x12\x45\n\x19resolved_update_item_node\x18\x41 \x01(\x0b\x32 .zetasql.ResolvedUpdateItemProtoH\x00\x12\x42\n\x17resolved_privilege_node\x18\x43 \x01(\x0b\x32\x1f.zetasql.ResolvedPrivilegeProtoH\x00\x12G\n\x1aresolved_argument_def_node\x18M \x01(\x0b\x32!.zetasql.ResolvedArgumentDefProtoH\x00\x12I\n\x1bresolved_argument_list_node\x18O \x01(\x0b\x32\".zetasql.ResolvedArgumentListProtoH\x00\x12Q\n\x1fresolved_function_argument_node\x18R \x01(\x0b\x32&.zetasql.ResolvedFunctionArgumentProtoH\x00\x12`\n\'resolved_function_signature_holder_node\x18T \x01(\x0b\x32-.zetasql.ResolvedFunctionSignatureHolderProtoH\x00\x12`\n\'resolved_aggregate_having_modifier_node\x18U \x01(\x0b\x32-.zetasql.ResolvedAggregateHavingModifierProtoH\x00\x12Q\n\x1fresolved_column_definition_node\x18[ \x01(\x0b\x32&.zetasql.ResolvedColumnDefinitionProtoH\x00\x12R\n resolved_set_operation_item_node\x18^ \x01(\x0b\x32&.zetasql.ResolvedSetOperationItemProtoH\x00\x12\x43\n\x18resolved_index_item_node\x18` \x01(\x0b\x32\x1f.zetasql.ResolvedIndexItemProtoH\x00\x12\x43\n\x18resolved_merge_when_node\x18\x64 \x01(\x0b\x32\x1f.zetasql.ResolvedMergeWhenProtoH\x00\x12T\n!resolved_update_item_element_node\x18\x66 \x01(\x0b\x32\'.zetasql.ResolvedUpdateItemElementProtoH\x00\x12S\n resolved_column_annotations_node\x18h \x01(\x0b\x32\'.zetasql.ResolvedColumnAnnotationsProtoH\x00\x12X\n#resolved_generated_column_info_node\x18i \x01(\x0b\x32).zetasql.ResolvedGeneratedColumnInfoProtoH\x00\x12:\n\x13resolved_model_node\x18m \x01(\x0b\x32\x1b.zetasql.ResolvedModelProtoH\x00\x12J\n\x1aresolved_alter_action_node\x18t \x01(\x0b\x32$.zetasql.AnyResolvedAlterActionProtoH\x00\x12\x45\n\x19resolved_unnest_item_node\x18~ \x01(\x0b\x32 .zetasql.ResolvedUnnestItemProtoH\x00\x12S\n resolved_replace_field_item_node\x18\x80\x01 \x01(\x0b\x32&.zetasql.ResolvedReplaceFieldItemProtoH\x00\x12\x45\n\x18resolved_connection_node\x18\x8d\x01 \x01(\x0b\x32 .zetasql.ResolvedConnectionProtoH\x00\x12\x63\n(resolved_execute_immediate_argument_node\x18\x8f\x01 \x01(\x0b\x32..zetasql.ResolvedExecuteImmediateArgumentProtoH\x00\x12\x45\n\x18resolved_descriptor_node\x18\x90\x01 \x01(\x0b\x32 .zetasql.ResolvedDescriptorProtoH\x00\x12Y\n#resolved_extended_cast_element_node\x18\x97\x01 \x01(\x0b\x32).zetasql.ResolvedExtendedCastElementProtoH\x00\x12[\n$resolved_with_partition_columns_node\x18\x99\x01 \x01(\x0b\x32*.zetasql.ResolvedWithPartitionColumnsProtoH\x00\x12J\n\x1bresolved_extended_cast_node\x18\x9e\x01 \x01(\x0b\x32\".zetasql.ResolvedExtendedCastProtoH\x00\x12J\n\x1bresolved_inline_lambda_node\x18\x9f\x01 \x01(\x0b\x32\".zetasql.ResolvedInlineLambdaProtoH\x00\x12H\n\x18resolved_constraint_node\x18\xa2\x01 \x01(\x0b\x32#.zetasql.AnyResolvedConstraintProtoH\x00\x12H\n\x1aresolved_pivot_column_node\x18\xa6\x01 \x01(\x0b\x32!.zetasql.ResolvedPivotColumnProtoH\x00\x12P\n\x1eresolved_returning_clause_node\x18\xaa\x01 \x01(\x0b\x32%.zetasql.ResolvedReturningClauseProtoH\x00\x12\x46\n\x19resolved_unpivot_arg_node\x18\xab\x01 \x01(\x0b\x32 .zetasql.ResolvedUnpivotArgProtoH\x00\x12O\n\x1eresolved_filter_field_arg_node\x18\xad\x01 \x01(\x0b\x32$.zetasql.ResolvedFilterFieldArgProtoH\x00\x12X\n#resolved_table_and_column_info_node\x18\xb3\x01 \x01(\x0b\x32(.zetasql.ResolvedTableAndColumnInfoProtoH\x00\x12W\n\"resolved_column_default_value_node\x18\xbc\x01 \x01(\x0b\x32(.zetasql.ResolvedColumnDefaultValueProtoH\x00\x12\x46\n\x19resolved_object_unit_node\x18\xc8\x01 \x01(\x0b\x32 .zetasql.ResolvedObjectUnitProtoH\x00\x12R\n\x1eresolved_graph_label_expr_node\x18\xd3\x01 \x01(\x0b\x32\'.zetasql.AnyResolvedGraphLabelExprProtoH\x00\x12_\n&resolved_graph_element_identifier_node\x18\xd9\x01 \x01(\x0b\x32,.zetasql.ResolvedGraphElementIdentifierProtoH\x00\x12[\n$resolved_graph_element_property_node\x18\xda\x01 \x01(\x0b\x32*.zetasql.ResolvedGraphElementPropertyProtoH\x00\x12i\n,resolved_aux_load_data_partition_filter_node\x18\xde\x01 \x01(\x0b\x32\x30.zetasql.ResolvedAuxLoadDataPartitionFilterProtoH\x00\x12U\n!resolved_graph_element_table_node\x18\xe0\x01 \x01(\x0b\x32\'.zetasql.ResolvedGraphElementTableProtoH\x00\x12\x62\n(resolved_graph_node_table_reference_node\x18\xe1\x01 \x01(\x0b\x32-.zetasql.ResolvedGraphNodeTableReferenceProtoH\x00\x12\x62\n(resolved_create_model_aliased_query_node\x18\xe2\x01 \x01(\x0b\x32-.zetasql.ResolvedCreateModelAliasedQueryProtoH\x00\x12U\n!resolved_graph_element_label_node\x18\xe6\x01 \x01(\x0b\x32\'.zetasql.ResolvedGraphElementLabelProtoH\x00\x12\x63\n(resolved_graph_property_declaration_node\x18\xe7\x01 \x01(\x0b\x32..zetasql.ResolvedGraphPropertyDeclarationProtoH\x00\x12\x61\n\'resolved_graph_property_definition_node\x18\xe8\x01 \x01(\x0b\x32-.zetasql.ResolvedGraphPropertyDefinitionProtoH\x00\x12\x41\n\x16resolved_sequence_node\x18\xe9\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedSequenceProtoH\x00\x12`\n\'resolved_grouping_set_multi_column_node\x18\xed\x01 \x01(\x0b\x32,.zetasql.ResolvedGroupingSetMultiColumnProtoH\x00\x12T\n\x1fresolved_grouping_set_base_node\x18\xee\x01 \x01(\x0b\x32(.zetasql.AnyResolvedGroupingSetBaseProtoH\x00\x12J\n\x1bresolved_grouping_call_node\x18\xf1\x01 \x01(\x0b\x32\".zetasql.ResolvedGroupingCallProtoH\x00\x12W\n\"resolved_identity_column_info_node\x18\xf4\x01 \x01(\x0b\x32(.zetasql.ResolvedIdentityColumnInfoProtoH\x00\x12h\n+resolved_graph_path_pattern_quantifier_node\x18\xf5\x01 \x01(\x0b\x32\x30.zetasql.ResolvedGraphPathPatternQuantifierProtoH\x00\x12Z\n\"resolved_computed_column_base_node\x18\xfd\x01 \x01(\x0b\x32+.zetasql.AnyResolvedComputedColumnBaseProtoH\x00\x12_\n&resolved_recursion_depth_modifier_node\x18\x80\x02 \x01(\x0b\x32,.zetasql.ResolvedRecursionDepthModifierProtoH\x00\x12`\n\'resolved_graph_make_array_variable_node\x18\x82\x02 \x01(\x0b\x32,.zetasql.ResolvedGraphMakeArrayVariableProtoH\x00\x12M\n\x1dresolved_graph_path_mode_node\x18\x83\x02 \x01(\x0b\x32#.zetasql.ResolvedGraphPathModeProtoH\x00\x12^\n&resolved_graph_path_search_prefix_node\x18\x84\x02 \x01(\x0b\x32+.zetasql.ResolvedGraphPathSearchPrefixProtoH\x00\x12t\n1resolved_match_recognize_variable_definition_node\x18\x8a\x02 \x01(\x0b\x32\x36.zetasql.ResolvedMatchRecognizeVariableDefinitionProtoH\x00\x12i\n*resolved_match_recognize_pattern_expr_node\x18\x8b\x02 \x01(\x0b\x32\x32.zetasql.AnyResolvedMatchRecognizePatternExprProtoH\x00\x12G\n\x19resolved_subpipeline_node\x18\x91\x02 \x01(\x0b\x32!.zetasql.ResolvedSubpipelineProtoH\x00\x12\x42\n\x17resolved_lock_mode_node\x18\x93\x02 \x01(\x0b\x32\x1e.zetasql.ResolvedLockModeProtoH\x00\x12G\n\x1aresolved_pipe_if_case_node\x18\x96\x02 \x01(\x0b\x32 .zetasql.ResolvedPipeIfCaseProtoH\x00\x12J\n\x1bresolved_output_schema_node\x18\x97\x02 \x01(\x0b\x32\".zetasql.ResolvedOutputSchemaProtoH\x00\x12J\n\x1bresolved_measure_group_node\x18\x98\x02 \x01(\x0b\x32\".zetasql.ResolvedMeasureGroupProtoH\x00\x12S\n resolved_on_conflict_clause_node\x18\x99\x02 \x01(\x0b\x32&.zetasql.ResolvedOnConflictClauseProtoH\x00\x12i\n+resolved_generalized_query_subpipeline_node\x18\x9c\x02 \x01(\x0b\x32\x31.zetasql.ResolvedGeneralizedQuerySubpipelineProtoH\x00\x12p\n/resolved_graph_dynamic_label_specification_node\x18\xa2\x02 \x01(\x0b\x32\x34.zetasql.ResolvedGraphDynamicLabelSpecificationProtoH\x00\x12z\n4resolved_graph_dynamic_properties_specification_node\x18\xa3\x02 \x01(\x0b\x32\x39.zetasql.ResolvedGraphDynamicPropertiesSpecificationProtoH\x00\x12Q\n\x1fresolved_update_field_item_node\x18\xa7\x02 \x01(\x0b\x32%.zetasql.ResolvedUpdateFieldItemProtoH\x00\x12M\n\x1dresolved_graph_path_cost_node\x18\xaa\x02 \x01(\x0b\x32#.zetasql.ResolvedGraphPathCostProtoH\x00\x42\x06\n\x04node\"C\n\x15ResolvedArgumentProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedNodeProto\"\xc7\x11\n\x14\x41nyResolvedExprProto\x12>\n\x15resolved_literal_node\x18\x03 \x01(\x0b\x32\x1d.zetasql.ResolvedLiteralProtoH\x00\x12\x42\n\x17resolved_parameter_node\x18\x04 \x01(\x0b\x32\x1f.zetasql.ResolvedParameterProtoH\x00\x12Q\n\x1fresolved_expression_column_node\x18\x05 \x01(\x0b\x32&.zetasql.ResolvedExpressionColumnProtoH\x00\x12\x43\n\x18resolved_column_ref_node\x18\x06 \x01(\x0b\x32\x1f.zetasql.ResolvedColumnRefProtoH\x00\x12U\n resolved_function_call_base_node\x18\x07 \x01(\x0b\x32).zetasql.AnyResolvedFunctionCallBaseProtoH\x00\x12\x38\n\x12resolved_cast_node\x18\x0b \x01(\x0b\x32\x1a.zetasql.ResolvedCastProtoH\x00\x12\x45\n\x19resolved_make_struct_node\x18\x0c \x01(\x0b\x32 .zetasql.ResolvedMakeStructProtoH\x00\x12\x43\n\x18resolved_make_proto_node\x18\r \x01(\x0b\x32\x1f.zetasql.ResolvedMakeProtoProtoH\x00\x12N\n\x1eresolved_get_struct_field_node\x18\x0f \x01(\x0b\x32$.zetasql.ResolvedGetStructFieldProtoH\x00\x12L\n\x1dresolved_get_proto_field_node\x18\x10 \x01(\x0b\x32#.zetasql.ResolvedGetProtoFieldProtoH\x00\x12I\n\x1bresolved_subquery_expr_node\x18\x11 \x01(\x0b\x32\".zetasql.ResolvedSubqueryExprProtoH\x00\x12\x44\n\x18resolved_dmldefault_node\x18< \x01(\x0b\x32 .zetasql.ResolvedDMLDefaultProtoH\x00\x12G\n\x1aresolved_argument_ref_node\x18N \x01(\x0b\x32!.zetasql.ResolvedArgumentRefProtoH\x00\x12@\n\x16resolved_constant_node\x18g \x01(\x0b\x32\x1e.zetasql.ResolvedConstantProtoH\x00\x12J\n\x1bresolved_replace_field_node\x18\x81\x01 \x01(\x0b\x32\".zetasql.ResolvedReplaceFieldProtoH\x00\x12M\n\x1dresolved_get_proto_oneof_node\x18\x82\x01 \x01(\x0b\x32#.zetasql.ResolvedGetProtoOneofProtoH\x00\x12N\n\x1dresolved_system_variable_node\x18\x8b\x01 \x01(\x0b\x32$.zetasql.ResolvedSystemVariableProtoH\x00\x12?\n\x15resolved_flatten_node\x18\x95\x01 \x01(\x0b\x32\x1d.zetasql.ResolvedFlattenProtoH\x00\x12J\n\x1bresolved_flattened_arg_node\x18\x96\x01 \x01(\x0b\x32\".zetasql.ResolvedFlattenedArgProtoH\x00\x12K\n\x1cresolved_get_json_field_node\x18\xa5\x01 \x01(\x0b\x32\".zetasql.ResolvedGetJsonFieldProtoH\x00\x12H\n\x1aresolved_filter_field_node\x18\xae\x01 \x01(\x0b\x32!.zetasql.ResolvedFilterFieldProtoH\x00\x12\x42\n\x17resolved_with_expr_node\x18\xc5\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedWithExprProtoH\x00\x12S\n resolved_catalog_column_ref_node\x18\xce\x01 \x01(\x0b\x32&.zetasql.ResolvedCatalogColumnRefProtoH\x00\x12\x62\n(resolved_graph_get_element_property_node\x18\xd2\x01 \x01(\x0b\x32-.zetasql.ResolvedGraphGetElementPropertyProtoH\x00\x12S\n resolved_graph_make_element_node\x18\xdb\x01 \x01(\x0b\x32&.zetasql.ResolvedGraphMakeElementProtoH\x00\x12N\n\x1dresolved_array_aggregate_node\x18\x81\x02 \x01(\x0b\x32$.zetasql.ResolvedArrayAggregateProtoH\x00\x12\x62\n(resolved_graph_is_labeled_predicate_node\x18\x86\x02 \x01(\x0b\x32-.zetasql.ResolvedGraphIsLabeledPredicateProtoH\x00\x12T\n resolved_update_constructor_node\x18\xa8\x02 \x01(\x0b\x32\'.zetasql.ResolvedUpdateConstructorProtoH\x00\x12I\n\x1bresolved_get_row_field_node\x18\xba\x02 \x01(\x0b\x32!.zetasql.ResolvedGetRowFieldProtoH\x00\x42\x06\n\x04node\"\x9b\x01\n\x11ResolvedExprProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedNodeProto\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x38\n\x13type_annotation_map\x18\x03 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProto\"\xc8\x01\n\x14ResolvedLiteralProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.zetasql.ValueWithTypeProto\x12\x19\n\x11has_explicit_type\x18\x03 \x01(\x08\x12\x18\n\x10\x66loat_literal_id\x18\x04 \x01(\x03\x12#\n\x1bpreserve_in_literal_remover\x18\x05 \x01(\x08\"x\n\x16ResolvedParameterProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08position\x18\x05 \x01(\x03\x12\x12\n\nis_untyped\x18\x03 \x01(\x08\"Y\n\x1dResolvedExpressionColumnProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x1dResolvedCatalogColumnRefProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\'\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x17.zetasql.ColumnRefProto\"\x89\x01\n\x16ResolvedColumnRefProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12,\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x15\n\ris_correlated\x18\x03 \x01(\x08\"\x8b\x01\n#ResolvedGroupingSetMultiColumnProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x34\n\x0b\x63olumn_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\"p\n\x15ResolvedConstantProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x08\x63onstant\x18\x02 \x01(\x0b\x32\x19.zetasql.ConstantRefProto\"\\\n\x1bResolvedSystemVariableProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x11\n\tname_path\x18\x02 \x03(\t\"\xe6\x01\n\x19ResolvedInlineLambdaProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x33\n\rargument_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x37\n\x0eparameter_list\x18\x03 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12+\n\x04\x62ody\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"t\n\x15ResolvedSequenceProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x08sequence\x18\x02 \x01(\x0b\x32\x19.zetasql.SequenceRefProto\"\x9f\x01\n\x1bResolvedFilterFieldArgProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0f\n\x07include\x18\x02 \x01(\x08\x12?\n\x15\x66ield_descriptor_path\x18\x03 \x03(\x0b\x32 .zetasql.FieldDescriptorRefProto\"\xdf\x01\n\x18ResolvedFilterFieldProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x43\n\x15\x66ilter_field_arg_list\x18\x03 \x03(\x0b\x32$.zetasql.ResolvedFilterFieldArgProto\x12%\n\x1dreset_cleared_required_fields\x18\x04 \x01(\x08\"\xe0\x01\n AnyResolvedFunctionCallBaseProto\x12I\n\x1bresolved_function_call_node\x18\x08 \x01(\x0b\x32\".zetasql.ResolvedFunctionCallProtoH\x00\x12i\n+resolved_non_scalar_function_call_base_node\x18V \x01(\x0b\x32\x32.zetasql.AnyResolvedNonScalarFunctionCallBaseProtoH\x00\x42\x06\n\x04node\"\xd9\x03\n\x1dResolvedFunctionCallBaseProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x19.zetasql.FunctionRefProto\x12\x32\n\tsignature\x18\x03 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\x34\n\rargument_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x45\n\x15generic_argument_list\x18\x06 \x03(\x0b\x32&.zetasql.ResolvedFunctionArgumentProto\x12\x44\n\nerror_mode\x18\x05 \x01(\x0e\x32\x30.zetasql.ResolvedFunctionCallBaseEnums.ErrorMode\x12/\n\thint_list\x18\x07 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x37\n\x0e\x63ollation_list\x18\x08 \x03(\x0b\x32\x1f.zetasql.ResolvedCollationProto\"\x97\x01\n\x19ResolvedFunctionCallProto\x12\x36\n\x06parent\x18\x01 \x01(\x0b\x32&.zetasql.ResolvedFunctionCallBaseProto\x12\x42\n\x12\x66unction_call_info\x18\x02 \x01(\x0b\x32&.zetasql.ResolvedFunctionCallInfoProto\"\xed\x01\n)AnyResolvedNonScalarFunctionCallBaseProto\x12\\\n%resolved_aggregate_function_call_node\x18\t \x01(\x0b\x32+.zetasql.ResolvedAggregateFunctionCallProtoH\x00\x12Z\n$resolved_analytic_function_call_node\x18\n \x01(\x0b\x32*.zetasql.ResolvedAnalyticFunctionCallProtoH\x00\x42\x06\n\x04node\"\x8b\x02\n&ResolvedNonScalarFunctionCallBaseProto\x12\x36\n\x06parent\x18\x01 \x01(\x0b\x32&.zetasql.ResolvedFunctionCallBaseProto\x12\x10\n\x08\x64istinct\x18\x02 \x01(\x08\x12\x64\n\x16null_handling_modifier\x18\x03 \x01(\x0e\x32\x44.zetasql.ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier\x12\x31\n\nwhere_expr\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xd7\x04\n\"ResolvedAggregateFunctionCallProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedNonScalarFunctionCallBaseProto\x12\x46\n\x0fhaving_modifier\x18\x05 \x01(\x0b\x32-.zetasql.ResolvedAggregateHavingModifierProto\x12=\n\x12order_by_item_list\x18\x03 \x03(\x0b\x32!.zetasql.ResolvedOrderByItemProto\x12,\n\x05limit\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x42\n\x12\x66unction_call_info\x18\x06 \x01(\x0b\x32&.zetasql.ResolvedFunctionCallInfoProto\x12;\n\rgroup_by_list\x18\x07 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\x38\n\x12group_by_hint_list\x18\n \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12L\n\x17group_by_aggregate_list\x18\x08 \x03(\x0b\x32+.zetasql.AnyResolvedComputedColumnBaseProto\x12\x32\n\x0bhaving_expr\x18\t \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x9d\x01\n!ResolvedAnalyticFunctionCallProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedNonScalarFunctionCallBaseProto\x12\x37\n\x0cwindow_frame\x18\x02 \x01(\x0b\x32!.zetasql.ResolvedWindowFrameProto\"\xcb\x01\n ResolvedExtendedCastElementProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12%\n\tfrom_type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12#\n\x07to_type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\x12+\n\x08\x66unction\x18\x04 \x01(\x0b\x32\x19.zetasql.FunctionRefProto\"\x8c\x01\n\x19ResolvedExtendedCastProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12?\n\x0c\x65lement_list\x18\x02 \x03(\x0b\x32).zetasql.ResolvedExtendedCastElementProto\"\xdb\x02\n\x11ResolvedCastProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x1c\n\x14return_null_on_error\x18\x03 \x01(\x08\x12\x39\n\rextended_cast\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedExtendedCastProto\x12-\n\x06\x66ormat\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x30\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x33\n\x0etype_modifiers\x18\x08 \x01(\x0b\x32\x1b.zetasql.TypeModifiersProto\"x\n\x17ResolvedMakeStructProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x31\n\nfield_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"~\n\x16ResolvedMakeProtoProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x38\n\nfield_list\x18\x02 \x03(\x0b\x32$.zetasql.ResolvedMakeProtoFieldProto\"\xe3\x01\n\x1bResolvedMakeProtoFieldProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12:\n\x10\x66ield_descriptor\x18\x02 \x01(\x0b\x32 .zetasql.FieldDescriptorRefProto\x12+\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x1b.zetasql.FieldFormat.Format\x12+\n\x04\x65xpr\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xab\x01\n\x1bResolvedGetStructFieldProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x11\n\tfield_idx\x18\x03 \x01(\x03\x12 \n\x18\x66ield_expr_is_positional\x18\x04 \x01(\x08\"\xd0\x02\n\x1aResolvedGetProtoFieldProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12:\n\x10\x66ield_descriptor\x18\x03 \x01(\x0b\x32 .zetasql.FieldDescriptorRefProto\x12\x32\n\rdefault_value\x18\x04 \x01(\x0b\x32\x1b.zetasql.ValueWithTypeProto\x12\x13\n\x0bget_has_bit\x18\x05 \x01(\x08\x12+\n\x06\x66ormat\x18\x06 \x01(\x0e\x32\x1b.zetasql.FieldFormat.Format\x12\'\n\x1freturn_default_value_when_unset\x18\x07 \x01(\x08\"\x88\x01\n\x19ResolvedGetJsonFieldProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x12\n\nfield_name\x18\x03 \x01(\t\"\x9c\x01\n\x18ResolvedGetRowFieldProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\'\n\x06\x63olumn\x18\x03 \x01(\x0b\x32\x17.zetasql.ColumnRefProto\"\xa6\x01\n\x14ResolvedFlattenProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x35\n\x0eget_field_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"G\n\x19ResolvedFlattenedArgProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\"\xd3\x01\n\x1dResolvedReplaceFieldItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x19\n\x11struct_index_path\x18\x03 \x03(\x03\x12:\n\x10proto_field_path\x18\x04 \x03(\x0b\x32 .zetasql.FieldDescriptorRefProto\"\xbd\x01\n\x19ResolvedReplaceFieldProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12G\n\x17replace_field_item_list\x18\x03 \x03(\x0b\x32&.zetasql.ResolvedReplaceFieldItemProto\"\xb1\x01\n\x1aResolvedGetProtoOneofProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12:\n\x10oneof_descriptor\x18\x03 \x01(\x0b\x32 .zetasql.OneofDescriptorRefProto\"\x91\x03\n\x19ResolvedSubqueryExprProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x46\n\rsubquery_type\x18\x02 \x01(\x0e\x32/.zetasql.ResolvedSubqueryExprEnums.SubqueryType\x12\x37\n\x0eparameter_list\x18\x03 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12.\n\x07in_expr\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x35\n\x0cin_collation\x18\x07 \x01(\x0b\x32\x1f.zetasql.ResolvedCollationProto\x12/\n\x08subquery\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12/\n\thint_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xaf\x01\n\x15ResolvedWithExprProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12=\n\x0f\x61ssignment_list\x18\x02 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12+\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xaf\x19\n\x14\x41nyResolvedScanProto\x12L\n\x1dresolved_single_row_scan_node\x18\x13 \x01(\x0b\x32#.zetasql.ResolvedSingleRowScanProtoH\x00\x12\x43\n\x18resolved_table_scan_node\x18\x14 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProtoH\x00\x12\x41\n\x17resolved_join_scan_node\x18\x15 \x01(\x0b\x32\x1e.zetasql.ResolvedJoinScanProtoH\x00\x12\x43\n\x18resolved_array_scan_node\x18\x16 \x01(\x0b\x32\x1f.zetasql.ResolvedArrayScanProtoH\x00\x12\x45\n\x19resolved_filter_scan_node\x18\x18 \x01(\x0b\x32 .zetasql.ResolvedFilterScanProtoH\x00\x12R\n resolved_set_operation_scan_node\x18\x1a \x01(\x0b\x32&.zetasql.ResolvedSetOperationScanProtoH\x00\x12H\n\x1bresolved_order_by_scan_node\x18\x1b \x01(\x0b\x32!.zetasql.ResolvedOrderByScanProtoH\x00\x12P\n\x1fresolved_limit_offset_scan_node\x18\x1c \x01(\x0b\x32%.zetasql.ResolvedLimitOffsetScanProtoH\x00\x12H\n\x1bresolved_with_ref_scan_node\x18\x1d \x01(\x0b\x32!.zetasql.ResolvedWithRefScanProtoH\x00\x12I\n\x1bresolved_analytic_scan_node\x18\x1e \x01(\x0b\x32\".zetasql.ResolvedAnalyticScanProtoH\x00\x12\x45\n\x19resolved_sample_scan_node\x18\x1f \x01(\x0b\x32 .zetasql.ResolvedSampleScanProtoH\x00\x12G\n\x1aresolved_project_scan_node\x18# \x01(\x0b\x32!.zetasql.ResolvedProjectScanProtoH\x00\x12\x41\n\x17resolved_with_scan_node\x18\x33 \x01(\x0b\x32\x1e.zetasql.ResolvedWithScanProtoH\x00\x12>\n\x15resolved_tvfscan_node\x18Q \x01(\x0b\x32\x1d.zetasql.ResolvedTVFScanProtoH\x00\x12Z\n$resolved_relation_argument_scan_node\x18Y \x01(\x0b\x32*.zetasql.ResolvedRelationArgumentScanProtoH\x00\x12W\n!resolved_aggregate_scan_base_node\x18o \x01(\x0b\x32*.zetasql.AnyResolvedAggregateScanBaseProtoH\x00\x12S\n resolved_recursive_ref_scan_node\x18\x93\x01 \x01(\x0b\x32&.zetasql.ResolvedRecursiveRefScanProtoH\x00\x12L\n\x1cresolved_recursive_scan_node\x18\x94\x01 \x01(\x0b\x32#.zetasql.ResolvedRecursiveScanProtoH\x00\x12\x44\n\x18resolved_pivot_scan_node\x18\xa1\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedPivotScanProtoH\x00\x12H\n\x1aresolved_unpivot_scan_node\x18\xac\x01 \x01(\x0b\x32!.zetasql.ResolvedUnpivotScanProtoH\x00\x12M\n\x1dresolved_group_rows_scan_node\x18\xb0\x01 \x01(\x0b\x32#.zetasql.ResolvedGroupRowsScanProtoH\x00\x12V\n\"resolved_execute_as_role_scan_node\x18\xcf\x01 \x01(\x0b\x32\'.zetasql.ResolvedExecuteAsRoleScanProtoH\x00\x12O\n\x1eresolved_graph_table_scan_node\x18\xd0\x01 \x01(\x0b\x32$.zetasql.ResolvedGraphTableScanProtoH\x00\x12Y\n\"resolved_graph_path_scan_base_node\x18\xf4\x01 \x01(\x0b\x32*.zetasql.AnyResolvedGraphPathScanBaseProtoH\x00\x12P\n\x1dresolved_graph_scan_base_node\x18\xf5\x01 \x01(\x0b\x32&.zetasql.AnyResolvedGraphScanBaseProtoH\x00\x12K\n\x1cresolved_graph_ref_scan_node\x18\xf6\x01 \x01(\x0b\x32\".zetasql.ResolvedGraphRefScanProtoH\x00\x12W\n\"resolved_static_describe_scan_node\x18\xfb\x01 \x01(\x0b\x32(.zetasql.ResolvedStaticDescribeScanProtoH\x00\x12\x46\n\x19resolved_assert_scan_node\x18\xfc\x01 \x01(\x0b\x32 .zetasql.ResolvedAssertScanProtoH\x00\x12H\n\x1aresolved_barrier_scan_node\x18\x85\x02 \x01(\x0b\x32!.zetasql.ResolvedBarrierScanProtoH\x00\x12W\n\"resolved_match_recognize_scan_node\x18\x89\x02 \x01(\x0b\x32(.zetasql.ResolvedMatchRecognizeScanProtoH\x00\x12@\n\x16resolved_log_scan_node\x18\x90\x02 \x01(\x0b\x32\x1d.zetasql.ResolvedLogScanProtoH\x00\x12[\n$resolved_subpipeline_input_scan_node\x18\x92\x02 \x01(\x0b\x32*.zetasql.ResolvedSubpipelineInputScanProtoH\x00\x12G\n\x1aresolved_pipe_if_scan_node\x18\x95\x02 \x01(\x0b\x32 .zetasql.ResolvedPipeIfScanProtoH\x00\x12K\n\x1cresolved_pipe_fork_scan_node\x18\x9b\x02 \x01(\x0b\x32\".zetasql.ResolvedPipeForkScanProtoH\x00\x12X\n#resolved_pipe_export_data_scan_node\x18\x9d\x02 \x01(\x0b\x32(.zetasql.ResolvedPipeExportDataScanProtoH\x00\x12Z\n$resolved_pipe_create_table_scan_node\x18\x9e\x02 \x01(\x0b\x32).zetasql.ResolvedPipeCreateTableScanProtoH\x00\x12I\n\x1bresolved_pipe_tee_scan_node\x18\xa1\x02 \x01(\x0b\x32!.zetasql.ResolvedPipeTeeScanProtoH\x00\x12O\n\x1eresolved_pipe_insert_scan_node\x18\xa9\x02 \x01(\x0b\x32$.zetasql.ResolvedPipeInsertScanProtoH\x00\x12M\n\x1dresolved_graph_call_scan_node\x18\xab\x02 \x01(\x0b\x32#.zetasql.ResolvedGraphCallScanProtoH\x00\x12J\n\x1bresolved_describe_scan_node\x18\xac\x02 \x01(\x0b\x32\".zetasql.ResolvedDescribeScanProtoH\x00\x12U\n!resolved_unset_argument_scan_node\x18\xad\x02 \x01(\x0b\x32\'.zetasql.ResolvedUnsetArgumentScanProtoH\x00\x42\x06\n\x04node\"\xcc\x01\n\x11ResolvedScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedNodeProto\x12\x31\n\x0b\x63olumn_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12/\n\thint_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x12\n\nis_ordered\x18\x04 \x01(\x08\x12\x13\n\x0bnode_source\x18\x05 \x01(\t\"\xfa\x01\n\x1eResolvedExecuteAsRoleScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x35\n\x15original_inlined_view\x18\x03 \x01(\x0b\x32\x16.zetasql.TableRefProto\x12\x42\n\x14original_inlined_tvf\x18\x04 \x01(\x0b\x32$.zetasql.TableValuedFunctionRefProto\"k\n\x12ResolvedModelProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12%\n\x05model\x18\x02 \x01(\x0b\x32\x16.zetasql.ModelRefProto\"z\n\x17ResolvedConnectionProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12/\n\nconnection\x18\x02 \x01(\x0b\x32\x1b.zetasql.ConnectionRefProto\"\xac\x01\n\x17ResolvedDescriptorProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12<\n\x16\x64\x65scriptor_column_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12#\n\x1b\x64\x65scriptor_column_name_list\x18\x03 \x03(\t\"H\n\x1aResolvedSingleRowScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"L\n\x1eResolvedUnsetArgumentScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"\xd3\x02\n\x16ResolvedTableScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12%\n\x05table\x18\x02 \x01(\x0b\x32\x16.zetasql.TableRefProto\x12;\n\x14\x66or_system_time_expr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x19\n\x11\x63olumn_index_list\x18\x04 \x03(\x03\x12\r\n\x05\x61lias\x18\x05 \x01(\t\x12\x31\n\tlock_mode\x18\x06 \x01(\x0b\x32\x1e.zetasql.ResolvedLockModeProto\x12\x18\n\x10read_as_row_type\x18\x07 \x01(\x08\x12\x32\n\x11table_column_list\x18\x08 \x03(\x0b\x32\x17.zetasql.ColumnRefProto\"\xf6\x02\n\x15ResolvedJoinScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12:\n\tjoin_type\x18\x02 \x01(\x0e\x32\'.zetasql.ResolvedJoinScanEnums.JoinType\x12\x30\n\tleft_scan\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x31\n\nright_scan\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x30\n\tjoin_expr\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x11\n\thas_using\x18\x06 \x01(\x08\x12\x12\n\nis_lateral\x18\x07 \x01(\x08\x12\x37\n\x0eparameter_list\x18\x08 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\"\xa6\x03\n\x16ResolvedArrayScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x36\n\x0f\x61rray_expr_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x39\n\x13\x65lement_column_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12?\n\x13\x61rray_offset_column\x18\x05 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12\x30\n\tjoin_expr\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x10\n\x08is_outer\x18\x07 \x01(\x08\x12\x35\n\x0e\x61rray_zip_mode\x18\x08 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"y\n\x19ResolvedColumnHolderProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12,\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\xac\x01\n\x17ResolvedFilterScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x32\n\x0b\x66ilter_expr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xba\x01\n\x19ResolvedGroupingCallProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x38\n\x0fgroup_by_column\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12\x33\n\routput_column\x18\x03 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\x98\x03\n\x1f\x41nyResolvedGroupingSetBaseProto\x12G\n\x1aresolved_grouping_set_node\x18] \x01(\x0b\x32!.zetasql.ResolvedGroupingSetProtoH\x00\x12=\n\x14resolved_rollup_node\x18\xef\x01 \x01(\x0b\x32\x1c.zetasql.ResolvedRollupProtoH\x00\x12\x39\n\x12resolved_cube_node\x18\xf0\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedCubeProtoH\x00\x12Q\n\x1fresolved_grouping_set_list_node\x18\xae\x02 \x01(\x0b\x32%.zetasql.ResolvedGroupingSetListProtoH\x00\x12W\n\"resolved_grouping_set_product_node\x18\xaf\x02 \x01(\x0b\x32(.zetasql.ResolvedGroupingSetProductProtoH\x00\x42\x06\n\x04node\"N\n\x1cResolvedGroupingSetBaseProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\"\x92\x01\n\x1cResolvedGroupingSetListProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedGroupingSetBaseProto\x12;\n\telem_list\x18\x02 \x03(\x0b\x32(.zetasql.AnyResolvedGroupingSetBaseProto\"\x96\x01\n\x1fResolvedGroupingSetProductProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedGroupingSetBaseProto\x12<\n\ninput_list\x18\x02 \x03(\x0b\x32(.zetasql.AnyResolvedGroupingSetBaseProto\"\x90\x01\n\x18ResolvedGroupingSetProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedGroupingSetBaseProto\x12=\n\x14group_by_column_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\"\x96\x01\n\x13ResolvedRollupProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedGroupingSetBaseProto\x12H\n\x12rollup_column_list\x18\x02 \x03(\x0b\x32,.zetasql.ResolvedGroupingSetMultiColumnProto\"\x92\x01\n\x11ResolvedCubeProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedGroupingSetBaseProto\x12\x46\n\x10\x63ube_column_list\x18\x02 \x03(\x0b\x32,.zetasql.ResolvedGroupingSetMultiColumnProto\"\xc8\x03\n!AnyResolvedAggregateScanBaseProto\x12K\n\x1cresolved_aggregate_scan_node\x18\x19 \x01(\x0b\x32#.zetasql.ResolvedAggregateScanProtoH\x00\x12`\n\'resolved_anonymized_aggregate_scan_node\x18p \x01(\x0b\x32-.zetasql.ResolvedAnonymizedAggregateScanProtoH\x00\x12t\n1resolved_differential_privacy_aggregate_scan_node\x18\xdd\x01 \x01(\x0b\x32\x36.zetasql.ResolvedDifferentialPrivacyAggregateScanProtoH\x00\x12v\n2resolved_aggregation_threshold_aggregate_scan_node\x18\xe4\x01 \x01(\x0b\x32\x37.zetasql.ResolvedAggregationThresholdAggregateScanProtoH\x00\x42\x06\n\x04node\"\xfc\x03\n\x1eResolvedAggregateScanBaseProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12;\n\rgroup_by_list\x18\x03 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\x37\n\x0e\x63ollation_list\x18\x05 \x03(\x0b\x32\x1f.zetasql.ResolvedCollationProto\x12\x43\n\x0e\x61ggregate_list\x18\x04 \x03(\x0b\x32+.zetasql.AnyResolvedComputedColumnBaseProto\x12\x43\n\x11grouping_set_list\x18\x06 \x03(\x0b\x32(.zetasql.AnyResolvedGroupingSetBaseProto\x12;\n\x12rollup_column_list\x18\x07 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12>\n\x12grouping_call_list\x18\x08 \x03(\x0b\x32\".zetasql.ResolvedGroupingCallProto\"U\n\x1aResolvedAggregateScanProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAggregateScanBaseProto\"\xd9\x01\n$ResolvedAnonymizedAggregateScanProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAggregateScanBaseProto\x12\x37\n\x10k_threshold_expr\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12?\n\x19\x61nonymization_option_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xe2\x01\n-ResolvedDifferentialPrivacyAggregateScanProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAggregateScanBaseProto\x12\x45\n\x1egroup_selection_threshold_expr\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\x0boption_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x9c\x01\n.ResolvedAggregationThresholdAggregateScanProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAggregateScanBaseProto\x12\x31\n\x0boption_list\x18\x05 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xb6\x01\n\x1dResolvedSetOperationItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x38\n\x12output_column_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\xa0\x03\n\x1dResolvedSetOperationScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12H\n\x07op_type\x18\x02 \x01(\x0e\x32\x37.zetasql.ResolvedSetOperationScanEnums.SetOperationType\x12?\n\x0finput_item_list\x18\x04 \x03(\x0b\x32&.zetasql.ResolvedSetOperationItemProto\x12]\n\x11\x63olumn_match_mode\x18\x05 \x01(\x0e\x32\x42.zetasql.ResolvedSetOperationScanEnums.SetOperationColumnMatchMode\x12i\n\x17\x63olumn_propagation_mode\x18\x06 \x01(\x0e\x32H.zetasql.ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode\"\xb8\x01\n\x18ResolvedOrderByScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12=\n\x12order_by_item_list\x18\x03 \x03(\x0b\x32!.zetasql.ResolvedOrderByItemProto\"\xda\x01\n\x1cResolvedLimitOffsetScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12,\n\x05limit\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12-\n\x06offset\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"_\n\x18ResolvedWithRefScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x17\n\x0fwith_query_name\x18\x02 \x01(\t\"\xc4\x01\n\x19ResolvedAnalyticScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12H\n\x13\x66unction_group_list\x18\x03 \x03(\x0b\x32+.zetasql.ResolvedAnalyticFunctionGroupProto\"\xa1\x03\n\x17ResolvedSampleScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x0e\n\x06method\x18\x03 \x01(\t\x12+\n\x04size\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x39\n\x04unit\x18\x05 \x01(\x0e\x32+.zetasql.ResolvedSampleScanEnums.SampleUnit\x12:\n\x13repeatable_argument\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x39\n\rweight_column\x18\x07 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12\x38\n\x11partition_by_list\x18\x08 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x88\x01\n\"AnyResolvedComputedColumnBaseProto\x12Z\n\"resolved_computed_column_impl_node\x18\xfe\x01 \x01(\x0b\x32+.zetasql.AnyResolvedComputedColumnImplProtoH\x00\x42\x06\n\x04node\"Q\n\x1fResolvedComputedColumnBaseProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\"\xdc\x01\n\"AnyResolvedComputedColumnImplProto\x12M\n\x1dresolved_computed_column_node\x18  \x01(\x0b\x32$.zetasql.ResolvedComputedColumnProtoH\x00\x12_\n&resolved_deferred_computed_column_node\x18\xff\x01 \x01(\x0b\x32,.zetasql.ResolvedDeferredComputedColumnProtoH\x00\x42\x06\n\x04node\"[\n\x1fResolvedComputedColumnImplProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ResolvedComputedColumnBaseProto\"\xb2\x01\n\x1bResolvedComputedColumnProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ResolvedComputedColumnImplProto\x12,\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12+\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xf4\x01\n#ResolvedDeferredComputedColumnProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ResolvedComputedColumnImplProto\x12,\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12+\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x38\n\x12side_effect_column\x18\x04 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\xc6\x02\n\x18ResolvedOrderByItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x33\n\ncolumn_ref\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12\x35\n\x0e\x63ollation_name\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x15\n\ris_descending\x18\x04 \x01(\x08\x12\x43\n\nnull_order\x18\x05 \x01(\x0e\x32/.zetasql.ResolvedOrderByItemEnums.NullOrderMode\x12\x32\n\tcollation\x18\x06 \x01(\x0b\x32\x1f.zetasql.ResolvedCollationProto\"\xc0\x02\n\x1eResolvedColumnAnnotationsProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x35\n\x0e\x63ollation_name\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x10\n\x08not_null\x18\x02 \x01(\x08\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12;\n\nchild_list\x18\x04 \x03(\x0b\x32\'.zetasql.ResolvedColumnAnnotationsProto\x12\x35\n\x0ftype_parameters\x18\x05 \x01(\x0b\x32\x1c.zetasql.TypeParametersProto\"\xe9\x02\n ResolvedGeneratedColumnInfoProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x31\n\nexpression\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12I\n\x0bstored_mode\x18\x05 \x01(\x0e\x32\x34.zetasql.ResolvedGeneratedColumnInfoEnums.StoredMode\x12O\n\x0egenerated_mode\x18\x06 \x01(\x0e\x32\x37.zetasql.ResolvedGeneratedColumnInfoEnums.GeneratedMode\x12\x46\n\x14identity_column_info\x18\x07 \x01(\x0b\x32(.zetasql.ResolvedIdentityColumnInfoProto\"\x91\x01\n\x1fResolvedColumnDefaultValueProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x31\n\nexpression\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x0b\n\x03sql\x18\x03 \x01(\t\"\x89\x03\n\x1dResolvedColumnDefinitionProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\x12<\n\x0b\x61nnotations\x18\x04 \x01(\x0b\x32\'.zetasql.ResolvedColumnAnnotationsProto\x12\x11\n\tis_hidden\x18\x05 \x01(\x08\x12,\n\x06\x63olumn\x18\x06 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12H\n\x15generated_column_info\x18\x07 \x01(\x0b\x32).zetasql.ResolvedGeneratedColumnInfoProto\x12?\n\rdefault_value\x18\t \x01(\x0b\x32(.zetasql.ResolvedColumnDefaultValueProto\"\x83\x02\n\x1a\x41nyResolvedConstraintProto\x12\x45\n\x19resolved_primary_key_node\x18\\ \x01(\x0b\x32 .zetasql.ResolvedPrimaryKeyProtoH\x00\x12\x45\n\x19resolved_foreign_key_node\x18n \x01(\x0b\x32 .zetasql.ResolvedForeignKeyProtoH\x00\x12O\n\x1eresolved_check_constraint_node\x18q \x01(\x0b\x32%.zetasql.ResolvedCheckConstraintProtoH\x00\x42\x06\n\x04node\"I\n\x17ResolvedConstraintProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\"\xe1\x01\n\x17ResolvedPrimaryKeyProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ResolvedConstraintProto\x12\x1a\n\x12\x63olumn_offset_list\x18\x02 \x03(\x03\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x12\n\nunenforced\x18\x04 \x01(\x08\x12\x17\n\x0f\x63onstraint_name\x18\x05 \x01(\t\x12\x18\n\x10\x63olumn_name_list\x18\x06 \x03(\t\"\x9d\x04\n\x17ResolvedForeignKeyProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ResolvedConstraintProto\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12&\n\x1ereferencing_column_offset_list\x18\x03 \x03(\x03\x12\x30\n\x10referenced_table\x18\x04 \x01(\x0b\x32\x16.zetasql.TableRefProto\x12%\n\x1dreferenced_column_offset_list\x18\x05 \x03(\x03\x12>\n\nmatch_mode\x18\x06 \x01(\x0e\x32*.zetasql.ResolvedForeignKeyEnums.MatchMode\x12G\n\rupdate_action\x18\x07 \x01(\x0e\x32\x30.zetasql.ResolvedForeignKeyEnums.ActionOperation\x12G\n\rdelete_action\x18\x08 \x01(\x0e\x32\x30.zetasql.ResolvedForeignKeyEnums.ActionOperation\x12\x10\n\x08\x65nforced\x18\t \x01(\x08\x12\x31\n\x0boption_list\x18\n \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x1f\n\x17referencing_column_list\x18\x0b \x03(\t\"\xe1\x01\n\x1cResolvedCheckConstraintProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ResolvedConstraintProto\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\x31\n\nexpression\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x10\n\x08\x65nforced\x18\x04 \x01(\x08\x12\x31\n\x0boption_list\x18\x05 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x87\x01\n\x19ResolvedOutputColumnProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\x06\x63olumn\x18\x03 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\xa3\x01\n\x19ResolvedOutputSchemaProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12>\n\x12output_column_list\x18\x02 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x16\n\x0eis_value_table\x18\x03 \x01(\x08\"\xb2\x01\n\x18ResolvedProjectScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x37\n\texpr_list\x18\x02 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\x31\n\ninput_scan\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\xcf\x02\n\x14ResolvedTVFScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\x03tvf\x18\x02 \x01(\x0b\x32$.zetasql.TableValuedFunctionRefProto\x12-\n\tsignature\x18\x03 \x01(\x0b\x32\x1a.zetasql.TVFSignatureProto\x12=\n\rargument_list\x18\x05 \x03(\x0b\x32&.zetasql.ResolvedFunctionArgumentProto\x12\x19\n\x11\x63olumn_index_list\x18\x08 \x03(\x03\x12\r\n\x05\x61lias\x18\x06 \x01(\t\x12@\n\x17\x66unction_call_signature\x18\x07 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\"\x98\x01\n\x1aResolvedGroupRowsScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12?\n\x11input_column_list\x18\x02 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\r\n\x05\x61lias\x18\x03 \x01(\t\"\xb5\x04\n\x1dResolvedFunctionArgumentProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12+\n\x04scan\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12*\n\x05model\x18\x05 \x01(\x0b\x32\x1b.zetasql.ResolvedModelProto\x12\x34\n\nconnection\x18\x06 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\x12\x38\n\x0e\x64\x65scriptor_arg\x18\x07 \x01(\x0b\x32 .zetasql.ResolvedDescriptorProto\x12:\n\x14\x61rgument_column_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x39\n\rinline_lambda\x18\x08 \x01(\x0b\x32\".zetasql.ResolvedInlineLambdaProto\x12\x30\n\x08sequence\x18\t \x01(\x0b\x32\x1e.zetasql.ResolvedSequenceProto\x12-\n\x05graph\x18\x0b \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x16\n\x0e\x61rgument_alias\x18\n \x01(\t\"\x99 \n\x19\x41nyResolvedStatementProto\x12G\n\x1aresolved_explain_stmt_node\x18% \x01(\x0b\x32!.zetasql.ResolvedExplainStmtProtoH\x00\x12\x43\n\x18resolved_query_stmt_node\x18& \x01(\x0b\x32\x1f.zetasql.ResolvedQueryStmtProtoH\x00\x12R\n\x1eresolved_create_statement_node\x18\' \x01(\x0b\x32(.zetasql.AnyResolvedCreateStatementProtoH\x00\x12N\n\x1eresolved_export_data_stmt_node\x18+ \x01(\x0b\x32$.zetasql.ResolvedExportDataStmtProtoH\x00\x12P\n\x1fresolved_define_table_stmt_node\x18, \x01(\x0b\x32%.zetasql.ResolvedDefineTableStmtProtoH\x00\x12I\n\x1bresolved_describe_stmt_node\x18- \x01(\x0b\x32\".zetasql.ResolvedDescribeStmtProtoH\x00\x12\x41\n\x17resolved_show_stmt_node\x18. \x01(\x0b\x32\x1e.zetasql.ResolvedShowStmtProtoH\x00\x12\x43\n\x18resolved_begin_stmt_node\x18/ \x01(\x0b\x32\x1f.zetasql.ResolvedBeginStmtProtoH\x00\x12\x45\n\x19resolved_commit_stmt_node\x18\x30 \x01(\x0b\x32 .zetasql.ResolvedCommitStmtProtoH\x00\x12I\n\x1bresolved_rollback_stmt_node\x18\x31 \x01(\x0b\x32\".zetasql.ResolvedRollbackStmtProtoH\x00\x12\x41\n\x17resolved_drop_stmt_node\x18\x32 \x01(\x0b\x32\x1e.zetasql.ResolvedDropStmtProtoH\x00\x12\x45\n\x19resolved_insert_stmt_node\x18? \x01(\x0b\x32 .zetasql.ResolvedInsertStmtProtoH\x00\x12\x45\n\x19resolved_delete_stmt_node\x18@ \x01(\x0b\x32 .zetasql.ResolvedDeleteStmtProtoH\x00\x12\x45\n\x19resolved_update_stmt_node\x18\x42 \x01(\x0b\x32 .zetasql.ResolvedUpdateStmtProtoH\x00\x12X\n\"resolved_grant_or_revoke_stmt_node\x18\x44 \x01(\x0b\x32*.zetasql.AnyResolvedGrantOrRevokeStmtProtoH\x00\x12\x64\n*resolved_alter_table_set_options_stmt_node\x18G \x01(\x0b\x32..zetasql.ResolvedAlterTableSetOptionsStmtProtoH\x00\x12\x45\n\x19resolved_rename_stmt_node\x18H \x01(\x0b\x32 .zetasql.ResolvedRenameStmtProtoH\x00\x12\x66\n+resolved_create_row_access_policy_stmt_node\x18I \x01(\x0b\x32/.zetasql.ResolvedCreateRowAccessPolicyStmtProtoH\x00\x12\x62\n)resolved_drop_row_access_policy_stmt_node\x18J \x01(\x0b\x32-.zetasql.ResolvedDropRowAccessPolicyStmtProtoH\x00\x12R\n resolved_drop_function_stmt_node\x18P \x01(\x0b\x32&.zetasql.ResolvedDropFunctionStmtProtoH\x00\x12\x41\n\x17resolved_call_stmt_node\x18S \x01(\x0b\x32\x1e.zetasql.ResolvedCallStmtProtoH\x00\x12\x45\n\x19resolved_import_stmt_node\x18V \x01(\x0b\x32 .zetasql.ResolvedImportStmtProtoH\x00\x12\x45\n\x19resolved_module_stmt_node\x18W \x01(\x0b\x32 .zetasql.ResolvedModuleStmtProtoH\x00\x12V\n\"resolved_create_database_stmt_node\x18_ \x01(\x0b\x32(.zetasql.ResolvedCreateDatabaseStmtProtoH\x00\x12\x45\n\x19resolved_assert_stmt_node\x18\x62 \x01(\x0b\x32 .zetasql.ResolvedAssertStmtProtoH\x00\x12\x43\n\x18resolved_merge_stmt_node\x18\x65 \x01(\x0b\x32\x1f.zetasql.ResolvedMergeStmtProtoH\x00\x12S\n\x1fresolved_alter_object_stmt_node\x18r \x01(\x0b\x32(.zetasql.AnyResolvedAlterObjectStmtProtoH\x00\x12V\n\"resolved_set_transaction_stmt_node\x18x \x01(\x0b\x32(.zetasql.ResolvedSetTransactionStmtProtoH\x00\x12\x63\n)resolved_drop_materialized_view_stmt_node\x18y \x01(\x0b\x32..zetasql.ResolvedDropMaterializedViewStmtProtoH\x00\x12N\n\x1eresolved_start_batch_stmt_node\x18z \x01(\x0b\x32$.zetasql.ResolvedStartBatchStmtProtoH\x00\x12J\n\x1cresolved_run_batch_stmt_node\x18{ \x01(\x0b\x32\".zetasql.ResolvedRunBatchStmtProtoH\x00\x12N\n\x1eresolved_abort_batch_stmt_node\x18| \x01(\x0b\x32$.zetasql.ResolvedAbortBatchStmtProtoH\x00\x12J\n\x1bresolved_truncate_stmt_node\x18\x85\x01 \x01(\x0b\x32\".zetasql.ResolvedTruncateStmtProtoH\x00\x12[\n$resolved_execute_immediate_stmt_node\x18\x8c\x01 \x01(\x0b\x32*.zetasql.ResolvedExecuteImmediateStmtProtoH\x00\x12N\n\x1dresolved_assignment_stmt_node\x18\x8e\x01 \x01(\x0b\x32$.zetasql.ResolvedAssignmentStmtProtoH\x00\x12Q\n\x1fresolved_export_model_stmt_node\x18\x98\x01 \x01(\x0b\x32%.zetasql.ResolvedExportModelStmtProtoH\x00\x12^\n&resolved_drop_table_function_stmt_node\x18\xaf\x01 \x01(\x0b\x32+.zetasql.ResolvedDropTableFunctionStmtProtoH\x00\x12M\n\x1dresolved_clone_data_stmt_node\x18\xb1\x01 \x01(\x0b\x32#.zetasql.ResolvedCloneDataStmtProtoH\x00\x12H\n\x1aresolved_analyze_stmt_node\x18\xb4\x01 \x01(\x0b\x32!.zetasql.ResolvedAnalyzeStmtProtoH\x00\x12^\n&resolved_drop_snapshot_table_stmt_node\x18\xb7\x01 \x01(\x0b\x32+.zetasql.ResolvedDropSnapshotTableStmtProtoH\x00\x12R\n resolved_aux_load_data_stmt_node\x18\xba\x01 \x01(\x0b\x32%.zetasql.ResolvedAuxLoadDataStmtProtoH\x00\x12l\n-resolved_drop_privilege_restriction_stmt_node\x18\xc0\x01 \x01(\x0b\x32\x32.zetasql.ResolvedDropPrivilegeRestrictionStmtProtoH\x00\x12\x46\n\x19resolved_undrop_stmt_node\x18\xe3\x01 \x01(\x0b\x32 .zetasql.ResolvedUndropStmtProtoH\x00\x12W\n\"resolved_export_metadata_stmt_node\x18\xea\x01 \x01(\x0b\x32(.zetasql.ResolvedExportMetadataStmtProtoH\x00\x12M\n\x1dresolved_drop_index_stmt_node\x18\xf2\x01 \x01(\x0b\x32#.zetasql.ResolvedDropIndexStmtProtoH\x00\x12[\n$resolved_generalized_query_stmt_node\x18\x9a\x02 \x01(\x0b\x32*.zetasql.ResolvedGeneralizedQueryStmtProtoH\x00\x12\x44\n\x18resolved_multi_stmt_node\x18\x9f\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedMultiStmtProtoH\x00\x12Z\n$resolved_create_with_entry_stmt_node\x18\xa0\x02 \x01(\x0b\x32).zetasql.ResolvedCreateWithEntryStmtProtoH\x00\x12P\n\x1eresolved_subpipeline_stmt_node\x18\xb4\x02 \x01(\x0b\x32%.zetasql.ResolvedSubpipelineStmtProtoH\x00\x12q\n0resolved_statement_with_pipe_operators_stmt_node\x18\xb6\x02 \x01(\x0b\x32\x34.zetasql.ResolvedStatementWithPipeOperatorsStmtProtoH\x00\x42\x06\n\x04node\"u\n\x16ResolvedStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedNodeProto\x12/\n\thint_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x82\x01\n\x18ResolvedExplainStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x35\n\tstatement\x18\x02 \x01(\x0b\x32\".zetasql.AnyResolvedStatementProto\"\xb5\x01\n+ResolvedStatementWithPipeOperatorsStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x35\n\tstatement\x18\x02 \x01(\x0b\x32\".zetasql.AnyResolvedStatementProto\x12\x1e\n\x16suffix_subpipeline_sql\x18\x03 \x01(\t\"\xcf\x01\n\x16ResolvedQueryStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12>\n\x12output_column_list\x18\x02 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x16\n\x0eis_value_table\x18\x03 \x01(\x08\x12,\n\x05query\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\xbd\x01\n!ResolvedGeneralizedQueryStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x39\n\routput_schema\x18\x02 \x01(\x0b\x32\".zetasql.ResolvedOutputSchemaProto\x12,\n\x05query\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\x85\x01\n\x16ResolvedMultiStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12:\n\x0estatement_list\x18\x02 \x03(\x0b\x32\".zetasql.AnyResolvedStatementProto\"\x88\x01\n ResolvedCreateWithEntryStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\nwith_entry\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedWithEntryProto\"\x98\x01\n\x1fResolvedCreateDatabaseStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x11\n\tname_path\x18\x02 \x03(\t\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x91\x0b\n\x1f\x41nyResolvedCreateStatementProto\x12V\n\"resolved_create_function_stmt_node\x18L \x01(\x0b\x32(.zetasql.ResolvedCreateFunctionStmtProtoH\x00\x12\x61\n(resolved_create_table_function_stmt_node\x18X \x01(\x0b\x32-.zetasql.ResolvedCreateTableFunctionStmtProtoH\x00\x12P\n\x1fresolved_create_index_stmt_node\x18\x61 \x01(\x0b\x32%.zetasql.ResolvedCreateIndexStmtProtoH\x00\x12V\n\"resolved_create_constant_stmt_node\x18\x63 \x01(\x0b\x32(.zetasql.ResolvedCreateConstantStmtProtoH\x00\x12\\\n$resolved_create_table_stmt_base_node\x18j \x01(\x0b\x32,.zetasql.AnyResolvedCreateTableStmtBaseProtoH\x00\x12P\n\x1fresolved_create_model_stmt_node\x18k \x01(\x0b\x32%.zetasql.ResolvedCreateModelStmtProtoH\x00\x12Q\n\x1eresolved_create_view_base_node\x18l \x01(\x0b\x32\'.zetasql.AnyResolvedCreateViewBaseProtoH\x00\x12X\n#resolved_create_procedure_stmt_node\x18} \x01(\x0b\x32).zetasql.ResolvedCreateProcedureStmtProtoH\x00\x12S\n resolved_create_entity_stmt_node\x18\x9a\x01 \x01(\x0b\x32&.zetasql.ResolvedCreateEntityStmtProtoH\x00\x12\x62\n(resolved_create_snapshot_table_stmt_node\x18\xb6\x01 \x01(\x0b\x32-.zetasql.ResolvedCreateSnapshotTableStmtProtoH\x00\x12p\n/resolved_create_privilege_restriction_stmt_node\x18\xbf\x01 \x01(\x0b\x32\x34.zetasql.ResolvedCreatePrivilegeRestrictionStmtProtoH\x00\x12\x62\n(resolved_create_property_graph_stmt_node\x18\xdf\x01 \x01(\x0b\x32-.zetasql.ResolvedCreatePropertyGraphStmtProtoH\x00\x12_\n%resolved_create_schema_stmt_base_node\x18\xf8\x01 \x01(\x0b\x32-.zetasql.AnyResolvedCreateSchemaStmtBaseProtoH\x00\x12[\n$resolved_create_connection_stmt_node\x18\x87\x02 \x01(\x0b\x32*.zetasql.ResolvedCreateConnectionStmtProtoH\x00\x12W\n\"resolved_create_sequence_stmt_node\x18\xb2\x02 \x01(\x0b\x32(.zetasql.ResolvedCreateSequenceStmtProtoH\x00\x42\x06\n\x04node\"\xf2\x01\n\x1cResolvedCreateStatementProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x11\n\tname_path\x18\x02 \x03(\t\x12G\n\x0c\x63reate_scope\x18\x05 \x01(\x0e\x32\x31.zetasql.ResolvedCreateStatementEnums.CreateScope\x12\x45\n\x0b\x63reate_mode\x18\x04 \x01(\x0e\x32\x30.zetasql.ResolvedCreateStatementEnums.CreateMode\"\xc4\x01\n\x16ResolvedIndexItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x33\n\ncolumn_ref\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12\x12\n\ndescending\x18\x03 \x01(\x08\x12\x31\n\x0boption_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xf3\x01\n\x17ResolvedUnnestItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x31\n\narray_expr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x34\n\x0e\x65lement_column\x18\x03 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12?\n\x13\x61rray_offset_column\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\"\xe6\x04\n\x1cResolvedCreateIndexStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x17\n\x0ftable_name_path\x18\x02 \x03(\t\x12\x33\n\ntable_scan\x18\x03 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12\x11\n\tis_unique\x18\x04 \x01(\x08\x12\x11\n\tis_search\x18\n \x01(\x08\x12\x11\n\tis_vector\x18\x0c \x01(\x08\x12\x19\n\x11index_all_columns\x18\x0b \x01(\x08\x12\x38\n\x0findex_item_list\x18\x05 \x03(\x0b\x32\x1f.zetasql.ResolvedIndexItemProto\x12>\n\x17storing_expression_list\x18\t \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x38\n\x11partition_by_list\x18\r \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\x0boption_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x43\n\x15\x63omputed_columns_list\x18\x07 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\x41\n\x17unnest_expressions_list\x18\x08 \x03(\x0b\x32 .zetasql.ResolvedUnnestItemProto\"\xe9\x01\n$AnyResolvedCreateSchemaStmtBaseProto\x12S\n resolved_create_schema_stmt_node\x18\x9d\x01 \x01(\x0b\x32&.zetasql.ResolvedCreateSchemaStmtProtoH\x00\x12\x64\n)resolved_create_external_schema_stmt_node\x18\xf9\x01 \x01(\x0b\x32..zetasql.ResolvedCreateExternalSchemaStmtProtoH\x00\x42\x06\n\x04node\"\x8d\x01\n!ResolvedCreateSchemaStmtBaseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x92\x01\n\x1dResolvedCreateSchemaStmtProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ResolvedCreateSchemaStmtBaseProto\x12\x35\n\x0e\x63ollation_name\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x99\x01\n%ResolvedCreateExternalSchemaStmtProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ResolvedCreateSchemaStmtBaseProto\x12\x34\n\nconnection\x18\x02 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\"\xc6\x02\n#AnyResolvedCreateTableStmtBaseProto\x12\x62\n)resolved_create_table_as_select_stmt_node\x18( \x01(\x0b\x32-.zetasql.ResolvedCreateTableAsSelectStmtProtoH\x00\x12\x61\n(resolved_create_external_table_stmt_node\x18* \x01(\x0b\x32-.zetasql.ResolvedCreateExternalTableStmtProtoH\x00\x12P\n\x1fresolved_create_table_stmt_node\x18Z \x01(\x0b\x32%.zetasql.ResolvedCreateTableStmtProtoH\x00\x42\x06\n\x04node\"\xf8\x04\n ResolvedCreateTableStmtBaseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x46\n\x16\x63olumn_definition_list\x18\x03 \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\x12\x38\n\x12pseudo_column_list\x18\x07 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x35\n\x0bprimary_key\x18\x04 \x01(\x0b\x32 .zetasql.ResolvedPrimaryKeyProto\x12:\n\x10\x66oreign_key_list\x18\t \x03(\x0b\x32 .zetasql.ResolvedForeignKeyProto\x12\x44\n\x15\x63heck_constraint_list\x18\n \x03(\x0b\x32%.zetasql.ResolvedCheckConstraintProto\x12\x16\n\x0eis_value_table\x18\x08 \x01(\x08\x12*\n\nlike_table\x18\x0b \x01(\x0b\x32\x16.zetasql.TableRefProto\x12\x35\n\x0e\x63ollation_name\x18\x0c \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x34\n\nconnection\x18\r \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\"\xb0\x02\n\x1cResolvedCreateTableStmtProto\x12\x39\n\x06parent\x18\x01 \x01(\x0b\x32).zetasql.ResolvedCreateTableStmtBaseProto\x12\x31\n\nclone_from\x18\x07 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x30\n\tcopy_from\x18\x08 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x38\n\x11partition_by_list\x18\x05 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x36\n\x0f\x63luster_by_list\x18\x06 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xc1\x02\n$ResolvedCreateTableAsSelectStmtProto\x12\x39\n\x06parent\x18\x01 \x01(\x0b\x32).zetasql.ResolvedCreateTableStmtBaseProto\x12\x38\n\x11partition_by_list\x18\x05 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x36\n\x0f\x63luster_by_list\x18\x06 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12>\n\x12output_column_list\x18\x02 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12,\n\x05query\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\xd3\x01\n$ResolvedCreateModelAliasedQueryProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12,\n\x05query\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12>\n\x12output_column_list\x18\x04 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\"\xd9\x06\n\x1cResolvedCreateModelStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12>\n\x12output_column_list\x18\x03 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12,\n\x05query\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12I\n\x12\x61liased_query_list\x18\r \x03(\x0b\x32-.zetasql.ResolvedCreateModelAliasedQueryProto\x12K\n\x1btransform_input_column_list\x18\x08 \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\x12<\n\x0etransform_list\x18\x05 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12H\n\x1ctransform_output_column_list\x18\x06 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12[\n&transform_analytic_function_group_list\x18\x07 \x03(\x0b\x32+.zetasql.ResolvedAnalyticFunctionGroupProto\x12L\n\x1cinput_column_definition_list\x18\t \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\x12M\n\x1doutput_column_definition_list\x18\n \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\x12\x11\n\tis_remote\x18\x0b \x01(\x08\x12\x34\n\nconnection\x18\x0c \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\"\xbf\x02\n\x1e\x41nyResolvedCreateViewBaseProto\x12N\n\x1eresolved_create_view_stmt_node\x18) \x01(\x0b\x32$.zetasql.ResolvedCreateViewStmtProtoH\x00\x12g\n+resolved_create_materialized_view_stmt_node\x18w \x01(\x0b\x32\x30.zetasql.ResolvedCreateMaterializedViewStmtProtoH\x00\x12\\\n%resolved_create_approx_view_stmt_node\x18\xeb\x01 \x01(\x0b\x32*.zetasql.ResolvedCreateApproxViewStmtProtoH\x00\x42\x06\n\x04node\"\xdc\x03\n\x1bResolvedCreateViewBaseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12>\n\x12output_column_list\x18\x03 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x1c\n\x14has_explicit_columns\x18\t \x01(\x08\x12,\n\x05query\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x0b\n\x03sql\x18\x06 \x01(\t\x12G\n\x0csql_security\x18\x07 \x01(\x0e\x32\x31.zetasql.ResolvedCreateStatementEnums.SqlSecurity\x12\x16\n\x0eis_value_table\x18\x04 \x01(\x08\x12\x11\n\trecursive\x18\x08 \x01(\x08\x12\x46\n\x16\x63olumn_definition_list\x18\n \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\"S\n\x1bResolvedCreateViewStmtProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ResolvedCreateViewBaseProto\"\x9b\x01\n!ResolvedWithPartitionColumnsProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x46\n\x16\x63olumn_definition_list\x18\x02 \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\"\xc3\x01\n$ResolvedCreateSnapshotTableStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\nclone_from\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xad\x01\n$ResolvedCreateExternalTableStmtProto\x12\x39\n\x06parent\x18\x01 \x01(\x0b\x32).zetasql.ResolvedCreateTableStmtBaseProto\x12J\n\x16with_partition_columns\x18\x02 \x01(\x0b\x32*.zetasql.ResolvedWithPartitionColumnsProto\"\xd1\x01\n\x1cResolvedExportModelStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x17\n\x0fmodel_name_path\x18\x02 \x03(\t\x12\x34\n\nconnection\x18\x03 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\x12\x31\n\x0boption_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xbd\x02\n\x1bResolvedExportDataStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x34\n\nconnection\x18\x06 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12>\n\x12output_column_list\x18\x03 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x16\n\x0eis_value_table\x18\x04 \x01(\x08\x12,\n\x05query\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\xea\x01\n\x1fResolvedExportMetadataStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x1a\n\x12schema_object_kind\x18\x02 \x01(\t\x12\x11\n\tname_path\x18\x03 \x03(\t\x12\x34\n\nconnection\x18\x04 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\x12\x31\n\x0boption_list\x18\x05 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x95\x01\n\x1cResolvedDefineTableStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x11\n\tname_path\x18\x02 \x03(\t\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x8c\x01\n\x19ResolvedDescribeStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x11\n\tname_path\x18\x03 \x03(\t\x12\x16\n\x0e\x66rom_name_path\x18\x04 \x03(\t\"\xa1\x01\n\x15ResolvedShowStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\x11\n\tname_path\x18\x03 \x03(\t\x12\x30\n\tlike_expr\x18\x04 \x01(\x0b\x32\x1d.zetasql.ResolvedLiteralProto\"\xaf\x01\n\x16ResolvedBeginStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x46\n\x0fread_write_mode\x18\x03 \x01(\x0e\x32-.zetasql.ResolvedBeginStmtEnums.ReadWriteMode\x12\x1c\n\x14isolation_level_list\x18\x02 \x03(\t\"\xb8\x01\n\x1fResolvedSetTransactionStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x46\n\x0fread_write_mode\x18\x03 \x01(\x0e\x32-.zetasql.ResolvedBeginStmtEnums.ReadWriteMode\x12\x1c\n\x14isolation_level_list\x18\x02 \x03(\t\"J\n\x17ResolvedCommitStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\"L\n\x19ResolvedRollbackStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\"b\n\x1bResolvedStartBatchStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x12\n\nbatch_type\x18\x02 \x01(\t\"L\n\x19ResolvedRunBatchStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\"N\n\x1bResolvedAbortBatchStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\"\xc2\x01\n\x15ResolvedDropStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\x12\x11\n\tname_path\x18\x04 \x03(\t\x12:\n\tdrop_mode\x18\x05 \x01(\x0e\x32\'.zetasql.ResolvedDropStmtEnums.DropMode\"\x81\x01\n%ResolvedDropMaterializedViewStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\x12\x11\n\tname_path\x18\x04 \x03(\t\"~\n\"ResolvedDropSnapshotTableStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\x12\x11\n\tname_path\x18\x04 \x03(\t\"K\n\x1dResolvedRecursiveRefScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"\x81\x02\n#ResolvedRecursionDepthModifierProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x32\n\x0blower_bound\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x32\n\x0bupper_bound\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x42\n\x16recursion_depth_column\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\"\xec\x02\n\x1aResolvedRecursiveScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12N\n\x07op_type\x18\x02 \x01(\x0e\x32=.zetasql.ResolvedRecursiveScanEnums.RecursiveSetOperationType\x12\x42\n\x12non_recursive_term\x18\x03 \x01(\x0b\x32&.zetasql.ResolvedSetOperationItemProto\x12>\n\x0erecursive_term\x18\x04 \x01(\x0b\x32&.zetasql.ResolvedSetOperationItemProto\x12N\n\x18recursion_depth_modifier\x18\x05 \x01(\x0b\x32,.zetasql.ResolvedRecursionDepthModifierProto\"\xbe\x01\n\x15ResolvedWithScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x38\n\x0fwith_entry_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedWithEntryProto\x12,\n\x05query\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x11\n\trecursive\x18\x04 \x01(\x08\"\x97\x01\n\x16ResolvedWithEntryProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x17\n\x0fwith_query_name\x18\x02 \x01(\t\x12\x34\n\rwith_subquery\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\xd6\x01\n\x13ResolvedOptionProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x11\n\tqualifier\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12,\n\x05value\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12@\n\rassignment_op\x18\x05 \x01(\x0e\x32).zetasql.ResolvedOptionEnums.AssignmentOp\"\xf7\x01\n\x1fResolvedWindowPartitioningProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12:\n\x11partition_by_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12/\n\thint_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x37\n\x0e\x63ollation_list\x18\x04 \x03(\x0b\x32\x1f.zetasql.ResolvedCollationProto\"\xbd\x01\n\x1bResolvedWindowOrderingProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12=\n\x12order_by_item_list\x18\x02 \x03(\x0b\x32!.zetasql.ResolvedOrderByItemProto\x12/\n\thint_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xff\x01\n\x18ResolvedWindowFrameProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12?\n\nframe_unit\x18\x02 \x01(\x0e\x32+.zetasql.ResolvedWindowFrameEnums.FrameUnit\x12\x39\n\nstart_expr\x18\x03 \x01(\x0b\x32%.zetasql.ResolvedWindowFrameExprProto\x12\x37\n\x08\x65nd_expr\x18\x04 \x01(\x0b\x32%.zetasql.ResolvedWindowFrameExprProto\"\x99\x02\n\"ResolvedAnalyticFunctionGroupProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12>\n\x0cpartition_by\x18\x02 \x01(\x0b\x32(.zetasql.ResolvedWindowPartitioningProto\x12\x36\n\x08order_by\x18\x03 \x01(\x0b\x32$.zetasql.ResolvedWindowOrderingProto\x12K\n\x16\x61nalytic_function_list\x18\x04 \x03(\x0b\x32+.zetasql.AnyResolvedComputedColumnBaseProto\"\xcc\x01\n\x1cResolvedWindowFrameExprProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12I\n\rboundary_type\x18\x02 \x01(\x0e\x32\x32.zetasql.ResolvedWindowFrameExprEnums.BoundaryType\x12\x31\n\nexpression\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"u\n\x15ResolvedDMLValueProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"E\n\x17ResolvedDMLDefaultProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\"\x92\x01\n\x17ResolvedAssertStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x31\n\nexpression\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"~\n\x1fResolvedAssertRowsModifiedProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04rows\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xb8\x03\n\x1dResolvedOnConflictClauseProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12N\n\x0f\x63onflict_action\x18\x02 \x01(\x0e\x32\x35.zetasql.ResolvedOnConflictClauseEnums.ConflictAction\x12\x41\n\x1b\x63onflict_target_column_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x1e\n\x16unique_constraint_name\x18\x04 \x01(\t\x12\x38\n\x0finsert_row_scan\x18\x05 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12:\n\x10update_item_list\x18\x06 \x03(\x0b\x32 .zetasql.ResolvedUpdateItemProto\x12>\n\x17update_where_expression\x18\x07 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"|\n\x16ResolvedInsertRowProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x32\n\nvalue_list\x18\x02 \x03(\x0b\x32\x1e.zetasql.ResolvedDMLValueProto\"\xe5\x06\n\x17ResolvedInsertStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\ntable_scan\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12@\n\x0binsert_mode\x18\x03 \x01(\x0e\x32+.zetasql.ResolvedInsertStmtEnums.InsertMode\x12\x46\n\x14\x61ssert_rows_modified\x18\x04 \x01(\x0b\x32(.zetasql.ResolvedAssertRowsModifiedProto\x12\x38\n\treturning\x18\n \x01(\x0b\x32%.zetasql.ResolvedReturningClauseProto\x12\x38\n\x12insert_column_list\x18\x05 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12=\n\x14query_parameter_list\x18\t \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\x12,\n\x05query\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12>\n\x18query_output_column_list\x18\x08 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x31\n\x08row_list\x18\x07 \x03(\x0b\x32\x1f.zetasql.ResolvedInsertRowProto\x12H\n\x12\x63olumn_access_list\x18\x0b \x03(\x0e\x32,.zetasql.ResolvedStatementEnums.ObjectAccess\x12\x42\n\x12on_conflict_clause\x18\x10 \x01(\x0b\x32&.zetasql.ResolvedOnConflictClauseProto\x12\x35\n-topologically_sorted_generated_column_id_list\x18\x0e \x03(\x03\x12\x41\n\x1agenerated_column_expr_list\x18\x0f \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xbf\x03\n\x17ResolvedDeleteStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\ntable_scan\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12\x46\n\x14\x61ssert_rows_modified\x18\x03 \x01(\x0b\x32(.zetasql.ResolvedAssertRowsModifiedProto\x12\x38\n\treturning\x18\x06 \x01(\x0b\x32%.zetasql.ResolvedReturningClauseProto\x12H\n\x12\x63olumn_access_list\x18\x07 \x03(\x0e\x32,.zetasql.ResolvedStatementEnums.ObjectAccess\x12?\n\x13\x61rray_offset_column\x18\x05 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12\x31\n\nwhere_expr\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xd7\x03\n\x17ResolvedUpdateItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12-\n\x06target\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\tset_value\x18\x03 \x01(\x0b\x32\x1e.zetasql.ResolvedDMLValueProto\x12:\n\x0e\x65lement_column\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12I\n\x18update_item_element_list\x18\x08 \x03(\x0b\x32\'.zetasql.ResolvedUpdateItemElementProto\x12\x35\n\x0b\x64\x65lete_list\x18\x05 \x03(\x0b\x32 .zetasql.ResolvedDeleteStmtProto\x12\x35\n\x0bupdate_list\x18\x06 \x03(\x0b\x32 .zetasql.ResolvedUpdateStmtProto\x12\x35\n\x0binsert_list\x18\x07 \x03(\x0b\x32 .zetasql.ResolvedInsertStmtProto\"\xb9\x01\n\x1eResolvedUpdateItemElementProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x30\n\tsubscript\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x35\n\x0bupdate_item\x18\x03 \x01(\x0b\x32 .zetasql.ResolvedUpdateItemProto\"\xa7\x05\n\x17ResolvedUpdateStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\ntable_scan\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12H\n\x12\x63olumn_access_list\x18\x08 \x03(\x0e\x32,.zetasql.ResolvedStatementEnums.ObjectAccess\x12\x46\n\x14\x61ssert_rows_modified\x18\x03 \x01(\x0b\x32(.zetasql.ResolvedAssertRowsModifiedProto\x12\x38\n\treturning\x18\t \x01(\x0b\x32%.zetasql.ResolvedReturningClauseProto\x12?\n\x13\x61rray_offset_column\x18\x07 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12\x31\n\nwhere_expr\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12:\n\x10update_item_list\x18\x05 \x03(\x0b\x32 .zetasql.ResolvedUpdateItemProto\x12\x30\n\tfrom_scan\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x35\n-topologically_sorted_generated_column_id_list\x18\n \x03(\x03\x12\x41\n\x1agenerated_column_expr_list\x18\x0b \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xa6\x03\n\x16ResolvedMergeWhenProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12=\n\nmatch_type\x18\x02 \x01(\x0e\x32).zetasql.ResolvedMergeWhenEnums.MatchType\x12\x31\n\nmatch_expr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12?\n\x0b\x61\x63tion_type\x18\x04 \x01(\x0e\x32*.zetasql.ResolvedMergeWhenEnums.ActionType\x12\x38\n\x12insert_column_list\x18\x05 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x33\n\ninsert_row\x18\x06 \x01(\x0b\x32\x1f.zetasql.ResolvedInsertRowProto\x12:\n\x10update_item_list\x18\x07 \x03(\x0b\x32 .zetasql.ResolvedUpdateItemProto\"\xe8\x02\n\x16ResolvedMergeStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\ntable_scan\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12H\n\x12\x63olumn_access_list\x18\x06 \x03(\x0e\x32,.zetasql.ResolvedStatementEnums.ObjectAccess\x12\x30\n\tfrom_scan\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x31\n\nmerge_expr\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x39\n\x10when_clause_list\x18\x05 \x03(\x0b\x32\x1f.zetasql.ResolvedMergeWhenProto\"\xb4\x01\n\x19ResolvedTruncateStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\ntable_scan\x18\x03 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12\x31\n\nwhere_expr\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\\\n\x17ResolvedObjectUnitProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x11\n\tname_path\x18\x02 \x03(\t\"\x92\x01\n\x16ResolvedPrivilegeProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x13\n\x0b\x61\x63tion_type\x18\x02 \x01(\t\x12\x33\n\tunit_list\x18\x03 \x03(\x0b\x32 .zetasql.ResolvedObjectUnitProto\"\xb7\x01\n!AnyResolvedGrantOrRevokeStmtProto\x12\x43\n\x18resolved_grant_stmt_node\x18\x45 \x01(\x0b\x32\x1f.zetasql.ResolvedGrantStmtProtoH\x00\x12\x45\n\x19resolved_revoke_stmt_node\x18\x46 \x01(\x0b\x32 .zetasql.ResolvedRevokeStmtProtoH\x00\x42\x06\n\x04node\"\x87\x02\n\x1eResolvedGrantOrRevokeStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x37\n\x0eprivilege_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedPrivilegeProto\x12\x18\n\x10object_type_list\x18\x03 \x03(\t\x12\x11\n\tname_path\x18\x04 \x03(\t\x12\x14\n\x0cgrantee_list\x18\x05 \x03(\t\x12\x38\n\x11grantee_expr_list\x18\x06 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"Q\n\x16ResolvedGrantStmtProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedGrantOrRevokeStmtProto\"R\n\x17ResolvedRevokeStmtProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedGrantOrRevokeStmtProto\"\x87\x0b\n\x1f\x41nyResolvedAlterObjectStmtProto\x12\x64\n*resolved_alter_row_access_policy_stmt_node\x18K \x01(\x0b\x32..zetasql.ResolvedAlterRowAccessPolicyStmtProtoH\x00\x12N\n\x1eresolved_alter_table_stmt_node\x18s \x01(\x0b\x32$.zetasql.ResolvedAlterTableStmtProtoH\x00\x12L\n\x1dresolved_alter_view_stmt_node\x18v \x01(\x0b\x32#.zetasql.ResolvedAlterViewStmtProtoH\x00\x12\x65\n*resolved_alter_materialized_view_stmt_node\x18\x7f \x01(\x0b\x32/.zetasql.ResolvedAlterMaterializedViewStmtProtoH\x00\x12U\n!resolved_alter_database_stmt_node\x18\x86\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterDatabaseStmtProtoH\x00\x12p\n0resolved_alter_all_row_access_policies_stmt_node\x18\x91\x01 \x01(\x0b\x32\x33.zetasql.ResolvedAlterAllRowAccessPoliciesStmtProtoH\x00\x12Q\n\x1fresolved_alter_entity_stmt_node\x18\x9b\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterEntityStmtProtoH\x00\x12Q\n\x1fresolved_alter_schema_stmt_node\x18\xa0\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterSchemaStmtProtoH\x00\x12n\n.resolved_alter_privilege_restriction_stmt_node\x18\xc4\x01 \x01(\x0b\x32\x33.zetasql.ResolvedAlterPrivilegeRestrictionStmtProtoH\x00\x12O\n\x1eresolved_alter_model_stmt_node\x18\xcd\x01 \x01(\x0b\x32$.zetasql.ResolvedAlterModelStmtProtoH\x00\x12Z\n$resolved_alter_approx_view_stmt_node\x18\xec\x01 \x01(\x0b\x32).zetasql.ResolvedAlterApproxViewStmtProtoH\x00\x12\x62\n(resolved_alter_external_schema_stmt_node\x18\xfa\x01 \x01(\x0b\x32-.zetasql.ResolvedAlterExternalSchemaStmtProtoH\x00\x12Y\n#resolved_alter_connection_stmt_node\x18\x88\x02 \x01(\x0b\x32).zetasql.ResolvedAlterConnectionStmtProtoH\x00\x12O\n\x1eresolved_alter_index_stmt_node\x18\xa4\x02 \x01(\x0b\x32$.zetasql.ResolvedAlterIndexStmtProtoH\x00\x12U\n!resolved_alter_sequence_stmt_node\x18\xb3\x02 \x01(\x0b\x32\'.zetasql.ResolvedAlterSequenceStmtProtoH\x00\x42\x06\n\x04node\"\xb9\x01\n\x1cResolvedAlterObjectStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x11\n\tname_path\x18\x02 \x03(\t\x12?\n\x11\x61lter_action_list\x18\x03 \x03(\x0b\x32$.zetasql.AnyResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"W\n\x1eResolvedAlterDatabaseStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"\xeb\x01\n\x1bResolvedAlterIndexStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\x12\x17\n\x0ftable_name_path\x18\x02 \x03(\t\x12G\n\nindex_type\x18\x03 \x01(\x0e\x32\x33.zetasql.ResolvedAlterIndexStmtEnums.AlterIndexType\x12\x33\n\ntable_scan\x18\x04 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\"_\n&ResolvedAlterMaterializedViewStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"Y\n ResolvedAlterApproxViewStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"U\n\x1cResolvedAlterSchemaStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"]\n$ResolvedAlterExternalSchemaStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"T\n\x1bResolvedAlterModelStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"T\n\x1bResolvedAlterTableStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"S\n\x1aResolvedAlterViewStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"\xd1\x0f\n\x1b\x41nyResolvedAlterActionProto\x12R\n resolved_set_options_action_node\x18u \x01(\x0b\x32&.zetasql.ResolvedSetOptionsActionProtoH\x00\x12Q\n\x1fresolved_add_column_action_node\x18\x83\x01 \x01(\x0b\x32%.zetasql.ResolvedAddColumnActionProtoH\x00\x12S\n resolved_drop_column_action_node\x18\x84\x01 \x01(\x0b\x32&.zetasql.ResolvedDropColumnActionProtoH\x00\x12M\n\x1dresolved_grant_to_action_node\x18\x87\x01 \x01(\x0b\x32#.zetasql.ResolvedGrantToActionProtoH\x00\x12U\n!resolved_filter_using_action_node\x18\x88\x01 \x01(\x0b\x32\'.zetasql.ResolvedFilterUsingActionProtoH\x00\x12S\n resolved_revoke_from_action_node\x18\x89\x01 \x01(\x0b\x32&.zetasql.ResolvedRevokeFromActionProtoH\x00\x12O\n\x1eresolved_rename_to_action_node\x18\x8a\x01 \x01(\x0b\x32$.zetasql.ResolvedRenameToActionProtoH\x00\x12I\n\x1bresolved_set_as_action_node\x18\x9c\x01 \x01(\x0b\x32!.zetasql.ResolvedSetAsActionProtoH\x00\x12Y\n#resolved_add_constraint_action_node\x18\xa3\x01 \x01(\x0b\x32).zetasql.ResolvedAddConstraintActionProtoH\x00\x12[\n$resolved_drop_constraint_action_node\x18\xa4\x01 \x01(\x0b\x32*.zetasql.ResolvedDropConstraintActionProtoH\x00\x12\\\n%resolved_drop_primary_key_action_node\x18\xb8\x01 \x01(\x0b\x32*.zetasql.ResolvedDropPrimaryKeyActionProtoH\x00\x12W\n\"resolved_rename_column_action_node\x18\xb9\x01 \x01(\x0b\x32(.zetasql.ResolvedRenameColumnActionProtoH\x00\x12S\n resolved_set_collate_clause_node\x18\xbb\x01 \x01(\x0b\x32&.zetasql.ResolvedSetCollateClauseProtoH\x00\x12S\n resolved_restrict_to_action_node\x18\xc1\x01 \x01(\x0b\x32&.zetasql.ResolvedRestrictToActionProtoH\x00\x12g\n+resolved_add_to_restrictee_list_action_node\x18\xc2\x01 \x01(\x0b\x32/.zetasql.ResolvedAddToRestricteeListActionProtoH\x00\x12q\n0resolved_remove_from_restrictee_list_action_node\x18\xc3\x01 \x01(\x0b\x32\x34.zetasql.ResolvedRemoveFromRestricteeListActionProtoH\x00\x12X\n!resolved_alter_column_action_node\x18\xc9\x01 \x01(\x0b\x32*.zetasql.AnyResolvedAlterColumnActionProtoH\x00\x12\\\n%resolved_alter_sub_entity_action_node\x18\xca\x01 \x01(\x0b\x32*.zetasql.ResolvedAlterSubEntityActionProtoH\x00\x12X\n#resolved_add_sub_entity_action_node\x18\xcb\x01 \x01(\x0b\x32(.zetasql.ResolvedAddSubEntityActionProtoH\x00\x12Z\n$resolved_drop_sub_entity_action_node\x18\xcc\x01 \x01(\x0b\x32).zetasql.ResolvedDropSubEntityActionProtoH\x00\x12\x66\n*resolved_add_column_identifier_action_node\x18\xa5\x02 \x01(\x0b\x32/.zetasql.ResolvedAddColumnIdentifierActionProtoH\x00\x12L\n\x1cresolved_rebuild_action_node\x18\xa6\x02 \x01(\x0b\x32#.zetasql.ResolvedRebuildActionProtoH\x00\x42\x06\n\x04node\"J\n\x18ResolvedAlterActionProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\"\xb1\x06\n!AnyResolvedAlterColumnActionProto\x12\x64\n)resolved_alter_column_options_action_node\x18\xa9\x01 \x01(\x0b\x32..zetasql.ResolvedAlterColumnOptionsActionProtoH\x00\x12n\n/resolved_alter_column_drop_not_null_action_node\x18\xb2\x01 \x01(\x0b\x32\x32.zetasql.ResolvedAlterColumnDropNotNullActionProtoH\x00\x12n\n/resolved_alter_column_set_data_type_action_node\x18\xb5\x01 \x01(\x0b\x32\x32.zetasql.ResolvedAlterColumnSetDataTypeActionProtoH\x00\x12k\n-resolved_alter_column_set_default_action_node\x18\xc6\x01 \x01(\x0b\x32\x31.zetasql.ResolvedAlterColumnSetDefaultActionProtoH\x00\x12m\n.resolved_alter_column_drop_default_action_node\x18\xc7\x01 \x01(\x0b\x32\x32.zetasql.ResolvedAlterColumnDropDefaultActionProtoH\x00\x12q\n0resolved_alter_column_drop_generated_action_node\x18\xf3\x01 \x01(\x0b\x32\x34.zetasql.ResolvedAlterColumnDropGeneratedActionProtoH\x00\x12o\n/resolved_alter_column_set_generated_action_node\x18\xb0\x02 \x01(\x0b\x32\x33.zetasql.ResolvedAlterColumnSetGeneratedActionProtoH\x00\x42\x06\n\x04node\"y\n\x1eResolvedAlterColumnActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x0e\n\x06\x63olumn\x18\x03 \x01(\t\"\x85\x01\n\x1dResolvedSetOptionsActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xcb\x01\n!ResolvedAlterSubEntityActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12:\n\x0c\x61lter_action\x18\x04 \x01(\x0b\x32$.zetasql.AnyResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x05 \x01(\x08\"\xc5\x01\n\x1fResolvedAddSubEntityActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x32\n\x0coptions_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x18\n\x10is_if_not_exists\x18\x05 \x01(\x08\"\x8e\x01\n ResolvedDropSubEntityActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\xae\x01\n\x1cResolvedAddColumnActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x18\n\x10is_if_not_exists\x18\x02 \x01(\x08\x12\x41\n\x11\x63olumn_definition\x18\x03 \x01(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\"\xb7\x01\n&ResolvedAddColumnIdentifierActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x0coptions_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x18\n\x10is_if_not_exists\x18\x04 \x01(\x08\"O\n\x1aResolvedRebuildActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\"\xcf\x01\n ResolvedAddConstraintActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x18\n\x10is_if_not_exists\x18\x02 \x01(\x08\x12\x37\n\nconstraint\x18\x03 \x01(\x0b\x32#.zetasql.AnyResolvedConstraintProto\x12%\n\x05table\x18\x04 \x01(\x0b\x32\x16.zetasql.TableRefProto\"z\n!ResolvedDropConstraintActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\"l\n!ResolvedDropPrimaryKeyActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\"\x93\x01\n%ResolvedAlterColumnOptionsActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"d\n)ResolvedAlterColumnDropNotNullActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\"f\n+ResolvedAlterColumnDropGeneratedActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\"\xaf\x01\n*ResolvedAlterColumnSetGeneratedActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\x12H\n\x15generated_column_info\x18\x04 \x01(\x0b\x32).zetasql.ResolvedGeneratedColumnInfoProto\"\x93\x02\n)ResolvedAlterColumnSetDataTypeActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\x12(\n\x0cupdated_type\x18\x04 \x01(\x0b\x32\x12.zetasql.TypeProto\x12=\n\x17updated_type_parameters\x18\x05 \x01(\x0b\x32\x1c.zetasql.TypeParametersProto\x12\x44\n\x13updated_annotations\x18\x06 \x01(\x0b\x32\'.zetasql.ResolvedColumnAnnotationsProto\"\xa4\x01\n(ResolvedAlterColumnSetDefaultActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\x12?\n\rdefault_value\x18\x04 \x01(\x0b\x32(.zetasql.ResolvedColumnDefaultValueProto\"d\n)ResolvedAlterColumnDropDefaultActionProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedAlterColumnActionProto\"v\n\x1dResolvedDropColumnActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8a\x01\n\x1fResolvedRenameColumnActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08new_name\x18\x03 \x01(\t\"\x81\x01\n\x18ResolvedSetAsActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x18\n\x10\x65ntity_body_json\x18\x02 \x01(\t\x12\x18\n\x10\x65ntity_body_text\x18\x03 \x01(\t\"\x89\x01\n\x1dResolvedSetCollateClauseProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x35\n\x0e\x63ollation_name\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xb4\x01\n%ResolvedAlterTableSetOptionsStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x11\n\tname_path\x18\x02 \x03(\t\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\x8d\x01\n\x17ResolvedRenameStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x15\n\rold_name_path\x18\x03 \x03(\t\x12\x15\n\rnew_name_path\x18\x04 \x03(\t\"\xf1\x01\n+ResolvedCreatePrivilegeRestrictionStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12>\n\x15\x63olumn_privilege_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedPrivilegeProto\x12\x13\n\x0bobject_type\x18\x03 \x01(\t\x12\x36\n\x0frestrictee_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x96\x03\n&ResolvedCreateRowAccessPolicyStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x45\n\x0b\x63reate_mode\x18\x02 \x01(\x0e\x32\x30.zetasql.ResolvedCreateStatementEnums.CreateMode\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10target_name_path\x18\x04 \x03(\t\x12\x14\n\x0cgrantee_list\x18\x05 \x03(\t\x12\x38\n\x11grantee_expr_list\x18\t \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x33\n\ntable_scan\x18\x06 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12\x30\n\tpredicate\x18\x07 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x15\n\rpredicate_str\x18\x08 \x01(\t\"\xda\x01\n)ResolvedDropPrivilegeRestrictionStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\x12\x11\n\tname_path\x18\x04 \x03(\t\x12>\n\x15\x63olumn_privilege_list\x18\x05 \x03(\x0b\x32\x1f.zetasql.ResolvedPrivilegeProto\"\xaa\x01\n$ResolvedDropRowAccessPolicyStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x13\n\x0bis_drop_all\x18\x02 \x01(\x08\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x18\n\x10target_name_path\x18\x05 \x03(\t\"\xcd\x01\n\x1aResolvedDropIndexStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0ftable_name_path\x18\x04 \x03(\t\x12\x41\n\nindex_type\x18\x05 \x01(\x0e\x32-.zetasql.ResolvedDropIndexStmtEnums.IndexType\"\x89\x01\n\x1aResolvedGrantToActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x38\n\x11grantee_expr_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x8a\x01\n\x1dResolvedRestrictToActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x36\n\x0frestrictee_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xad\x01\n&ResolvedAddToRestricteeListActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x18\n\x10is_if_not_exists\x18\x02 \x01(\x08\x12\x36\n\x0frestrictee_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xae\x01\n+ResolvedRemoveFromRestricteeListActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x36\n\x0frestrictee_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x9c\x01\n\x1eResolvedFilterUsingActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x30\n\tpredicate\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x15\n\rpredicate_str\x18\x03 \x01(\t\"\xa8\x01\n\x1dResolvedRevokeFromActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x38\n\x11revokee_expr_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x1a\n\x12is_revoke_from_all\x18\x03 \x01(\x08\"b\n\x1bResolvedRenameToActionProto\x12\x31\n\x06parent\x18\x01 \x01(\x0b\x32!.zetasql.ResolvedAlterActionProto\x12\x10\n\x08new_path\x18\x02 \x03(\t\"\xb8\x01\n*ResolvedAlterPrivilegeRestrictionStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\x12>\n\x15\x63olumn_privilege_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedPrivilegeProto\x12\x13\n\x0bobject_type\x18\x03 \x01(\t\"\xa1\x01\n%ResolvedAlterRowAccessPolicyStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\ntable_scan\x18\x06 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\"\x98\x01\n*ResolvedAlterAllRowAccessPoliciesStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\x12\x33\n\ntable_scan\x18\x06 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\"\x85\x01\n\x1fResolvedCreateConstantStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xc6\x05\n\x1fResolvedCreateFunctionStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12 \n\x18has_explicit_return_type\x18\r \x01(\x08\x12\'\n\x0breturn_type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x1a\n\x12\x61rgument_name_list\x18\x0b \x03(\t\x12\x32\n\tsignature\x18\n \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\x14\n\x0cis_aggregate\x18\x08 \x01(\x08\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12G\n\x19\x61ggregate_expression_list\x18\t \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12:\n\x13\x66unction_expression\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\x0boption_list\x18\x07 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12G\n\x0csql_security\x18\x0c \x01(\x0e\x32\x31.zetasql.ResolvedCreateStatementEnums.SqlSecurity\x12Q\n\x11\x64\x65terminism_level\x18\x0e \x01(\x0e\x32\x36.zetasql.ResolvedCreateStatementEnums.DeterminismLevel\x12\x11\n\tis_remote\x18\x0f \x01(\x08\x12\x34\n\nconnection\x18\x10 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\"\xc1\x01\n\x18ResolvedArgumentDefProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x45\n\rargument_kind\x18\x04 \x01(\x0e\x32..zetasql.ResolvedArgumentDefEnums.ArgumentKind\"\x9b\x01\n\x18ResolvedArgumentRefProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\rargument_kind\x18\x03 \x01(\x0e\x32..zetasql.ResolvedArgumentDefEnums.ArgumentKind\"\xf3\x03\n$ResolvedCreateTableFunctionStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x1a\n\x12\x61rgument_name_list\x18\x02 \x03(\t\x12\x32\n\tsignature\x18\x03 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\"\n\x1ahas_explicit_return_schema\x18\x0b \x01(\x08\x12\x31\n\x0boption_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x10\n\x08language\x18\x05 \x01(\t\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12,\n\x05query\x18\x07 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12>\n\x12output_column_list\x18\x08 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x16\n\x0eis_value_table\x18\t \x01(\x08\x12G\n\x0csql_security\x18\n \x01(\x0e\x32\x31.zetasql.ResolvedCreateStatementEnums.SqlSecurity\"u\n!ResolvedRelationArgumentScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0eis_value_table\x18\x03 \x01(\x08\"\x80\x01\n\x19ResolvedArgumentListProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x33\n\x08\x61rg_list\x18\x02 \x03(\x0b\x32!.zetasql.ResolvedArgumentDefProto\"\x8a\x01\n$ResolvedFunctionSignatureHolderProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x32\n\tsignature\x18\x02 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\"\xf2\x01\n\x1dResolvedDropFunctionStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x11\n\tname_path\x18\x03 \x03(\t\x12\x35\n\targuments\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedArgumentListProto\x12@\n\tsignature\x18\x05 \x01(\x0b\x32-.zetasql.ResolvedFunctionSignatureHolderProto\"~\n\"ResolvedDropTableFunctionStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x11\n\tname_path\x18\x03 \x03(\t\"\xe1\x01\n\x15ResolvedCallStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12-\n\tprocedure\x18\x02 \x01(\x0b\x32\x1a.zetasql.ProcedureRefProto\x12\x32\n\tsignature\x18\x03 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\x34\n\rargument_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x92\x02\n\x17ResolvedImportStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12@\n\x0bimport_kind\x18\x02 \x01(\x0e\x32+.zetasql.ResolvedImportStmtEnums.ImportKind\x12\x11\n\tname_path\x18\x03 \x03(\t\x12\x11\n\tfile_path\x18\x04 \x01(\t\x12\x12\n\nalias_path\x18\x05 \x03(\t\x12\x17\n\x0finto_alias_path\x18\x07 \x03(\t\x12\x31\n\x0boption_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x90\x01\n\x17ResolvedModuleStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x11\n\tname_path\x18\x02 \x03(\t\x12\x31\n\x0boption_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xda\x01\n$ResolvedAggregateHavingModifierProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12N\n\x04kind\x18\x02 \x01(\x0e\x32@.zetasql.ResolvedAggregateHavingModifierEnums.HavingModifierKind\x12\x32\n\x0bhaving_expr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x88\x02\n\'ResolvedCreateMaterializedViewStmtProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ResolvedCreateViewBaseProto\x12\x38\n\x11partition_by_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x36\n\x0f\x63luster_by_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x35\n\x0ereplica_source\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"Y\n!ResolvedCreateApproxViewStmtProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ResolvedCreateViewBaseProto\"\x98\x03\n ResolvedCreateProcedureStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x1a\n\x12\x61rgument_name_list\x18\x02 \x03(\t\x12\x32\n\tsignature\x18\x03 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\x31\n\x0boption_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x16\n\x0eprocedure_body\x18\x05 \x01(\t\x12\x34\n\nconnection\x18\x06 \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x0c\n\x04\x63ode\x18\x08 \x01(\t\x12L\n\x11\x65xternal_security\x18\t \x01(\x0e\x32\x31.zetasql.ResolvedCreateStatementEnums.SqlSecurity\"\x98\x01\n%ResolvedExecuteImmediateArgumentProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n\nexpression\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xeb\x01\n!ResolvedExecuteImmediateStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12*\n\x03sql\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x1c\n\x14into_identifier_list\x18\x03 \x03(\t\x12K\n\x13using_argument_list\x18\x04 \x03(\x0b\x32..zetasql.ResolvedExecuteImmediateArgumentProto\"\xaa\x01\n\x1bResolvedAssignmentStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12-\n\x06target\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12+\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xd2\x01\n\x1dResolvedCreateEntityStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\x12\x18\n\x10\x65ntity_body_json\x18\x03 \x01(\t\x12\x18\n\x10\x65ntity_body_text\x18\x05 \x01(\t\x12\x31\n\x0boption_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"j\n\x1cResolvedAlterEntityStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\"\xad\x01\n\x18ResolvedPivotColumnProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12,\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x18\n\x10pivot_expr_index\x18\x03 \x01(\x03\x12\x19\n\x11pivot_value_index\x18\x04 \x01(\x03\"\x94\x03\n\x16ResolvedPivotScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12;\n\rgroup_by_list\x18\x03 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\x36\n\x0fpivot_expr_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12/\n\x08\x66or_expr\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x37\n\x10pivot_value_list\x18\x06 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12<\n\x11pivot_column_list\x18\x07 \x03(\x0b\x32!.zetasql.ResolvedPivotColumnProto\"\x82\x02\n\x1cResolvedReturningClauseProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12>\n\x12output_column_list\x18\x02 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x39\n\raction_column\x18\x03 \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12\x37\n\texpr_list\x18\x04 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\"\x7f\n\x17ResolvedUnpivotArgProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x34\n\x0b\x63olumn_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\"\xb7\x03\n\x18ResolvedUnpivotScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x37\n\x11value_column_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x32\n\x0clabel_column\x18\x04 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x31\n\nlabel_list\x18\x05 \x03(\x0b\x32\x1d.zetasql.ResolvedLiteralProto\x12:\n\x10unpivot_arg_list\x18\x06 \x03(\x0b\x32 .zetasql.ResolvedUnpivotArgProto\x12I\n\x1bprojected_input_column_list\x18\x07 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12\x15\n\rinclude_nulls\x18\x08 \x01(\x08\"\xfc\x05\n\x1fResolvedMatchRecognizeScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x31\n\x0boption_list\x18\t \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12Q\n\x1c\x61nalytic_function_group_list\x18\x03 \x03(\x0b\x32+.zetasql.ResolvedAnalyticFunctionGroupProto\x12`\n pattern_variable_definition_list\x18\x05 \x03(\x0b\x32\x36.zetasql.ResolvedMatchRecognizeVariableDefinitionProto\x12\x43\n\x07pattern\x18\x06 \x01(\x0b\x32\x32.zetasql.AnyResolvedMatchRecognizePatternExprProto\x12Z\n\x15\x61\x66ter_match_skip_mode\x18\x08 \x01(\x0e\x32;.zetasql.ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode\x12>\n\x12measure_group_list\x18\x07 \x03(\x0b\x32\".zetasql.ResolvedMeasureGroupProto\x12\x39\n\x13match_number_column\x18\n \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12=\n\x17match_row_number_column\x18\x0b \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x37\n\x11\x63lassifier_column\x18\x0c \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\xe6\x01\n\x19ResolvedMeasureGroupProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12T\n\x14pattern_variable_ref\x18\x02 \x01(\x0b\x32\x36.zetasql.ResolvedMatchRecognizePatternVariableRefProto\x12\x43\n\x0e\x61ggregate_list\x18\x03 \x03(\x0b\x32+.zetasql.AnyResolvedComputedColumnBaseProto\"\x9f\x01\n-ResolvedMatchRecognizeVariableDefinitionProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\tpredicate\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xee\x04\n)AnyResolvedMatchRecognizePatternExprProto\x12h\n+resolved_match_recognize_pattern_empty_node\x18\x8c\x02 \x01(\x0b\x32\x30.zetasql.ResolvedMatchRecognizePatternEmptyProtoH\x00\x12u\n2resolved_match_recognize_pattern_variable_ref_node\x18\x8d\x02 \x01(\x0b\x32\x36.zetasql.ResolvedMatchRecognizePatternVariableRefProtoH\x00\x12p\n/resolved_match_recognize_pattern_operation_node\x18\x8e\x02 \x01(\x0b\x32\x34.zetasql.ResolvedMatchRecognizePatternOperationProtoH\x00\x12z\n4resolved_match_recognize_pattern_quantification_node\x18\x8f\x02 \x01(\x0b\x32\x39.zetasql.ResolvedMatchRecognizePatternQuantificationProtoH\x00\x12j\n,resolved_match_recognize_pattern_anchor_node\x18\x94\x02 \x01(\x0b\x32\x31.zetasql.ResolvedMatchRecognizePatternAnchorProtoH\x00\x42\x06\n\x04node\"X\n&ResolvedMatchRecognizePatternExprProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\"j\n\'ResolvedMatchRecognizePatternEmptyProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedMatchRecognizePatternExprProto\"\xb1\x01\n(ResolvedMatchRecognizePatternAnchorProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedMatchRecognizePatternExprProto\x12\x44\n\x04mode\x18\x02 \x01(\x0e\x32\x36.zetasql.ResolvedMatchRecognizePatternAnchorEnums.Mode\"~\n-ResolvedMatchRecognizePatternVariableRefProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedMatchRecognizePatternExprProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xa2\x02\n+ResolvedMatchRecognizePatternOperationProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedMatchRecognizePatternExprProto\x12h\n\x07op_type\x18\x02 \x01(\x0e\x32W.zetasql.ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType\x12H\n\x0coperand_list\x18\x03 \x03(\x0b\x32\x32.zetasql.AnyResolvedMatchRecognizePatternExprProto\"\xb6\x02\n0ResolvedMatchRecognizePatternQuantificationProto\x12?\n\x06parent\x18\x01 \x01(\x0b\x32/.zetasql.ResolvedMatchRecognizePatternExprProto\x12\x43\n\x07operand\x18\x02 \x01(\x0b\x32\x32.zetasql.AnyResolvedMatchRecognizePatternExprProto\x12\x32\n\x0blower_bound\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x32\n\x0bupper_bound\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x14\n\x0cis_reluctant\x18\x05 \x01(\x08\"\xb7\x01\n\x1aResolvedCloneDataStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x35\n\x0ctarget_table\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12\x31\n\nclone_from\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\x93\x01\n\x1fResolvedTableAndColumnInfoProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12%\n\x05table\x18\x02 \x01(\x0b\x32\x16.zetasql.TableRefProto\x12\x19\n\x11\x63olumn_index_list\x18\x03 \x03(\x03\"\xcd\x01\n\x18ResolvedAnalyzeStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12M\n\x1btable_and_column_index_list\x18\x03 \x03(\x0b\x32(.zetasql.ResolvedTableAndColumnInfoProto\"\x9e\x01\n\'ResolvedAuxLoadDataPartitionFilterProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12-\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x14\n\x0cis_overwrite\x18\x03 \x01(\x08\"\xf2\x07\n\x1cResolvedAuxLoadDataStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12K\n\x0einsertion_mode\x18\x02 \x01(\x0e\x32\x33.zetasql.ResolvedAuxLoadDataStmtEnums.InsertionMode\x12\x15\n\ris_temp_table\x18\x11 \x01(\x08\x12\x11\n\tname_path\x18\x03 \x03(\t\x12J\n\x10partition_filter\x18\x10 \x01(\x0b\x32\x30.zetasql.ResolvedAuxLoadDataPartitionFilterProto\x12>\n\x12output_column_list\x18\x04 \x03(\x0b\x32\".zetasql.ResolvedOutputColumnProto\x12\x46\n\x16\x63olumn_definition_list\x18\x05 \x03(\x0b\x32&.zetasql.ResolvedColumnDefinitionProto\x12\x38\n\x12pseudo_column_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x35\n\x0bprimary_key\x18\x07 \x01(\x0b\x32 .zetasql.ResolvedPrimaryKeyProto\x12:\n\x10\x66oreign_key_list\x18\x08 \x03(\x0b\x32 .zetasql.ResolvedForeignKeyProto\x12\x44\n\x15\x63heck_constraint_list\x18\t \x03(\x0b\x32%.zetasql.ResolvedCheckConstraintProto\x12\x38\n\x11partition_by_list\x18\n \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x36\n\x0f\x63luster_by_list\x18\x0b \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\x0boption_list\x18\x0c \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12J\n\x16with_partition_columns\x18\r \x01(\x0b\x32*.zetasql.ResolvedWithPartitionColumnsProto\x12\x34\n\nconnection\x18\x0e \x01(\x0b\x32 .zetasql.ResolvedConnectionProto\x12<\n\x16\x66rom_files_option_list\x18\x0f \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xa4\x03\n$ResolvedCreatePropertyGraphStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12@\n\x0fnode_table_list\x18\x02 \x03(\x0b\x32\'.zetasql.ResolvedGraphElementTableProto\x12@\n\x0f\x65\x64ge_table_list\x18\x03 \x03(\x0b\x32\'.zetasql.ResolvedGraphElementTableProto\x12;\n\nlabel_list\x18\x04 \x03(\x0b\x32\'.zetasql.ResolvedGraphElementLabelProto\x12Q\n\x19property_declaration_list\x18\x05 \x03(\x0b\x32..zetasql.ResolvedGraphPropertyDeclarationProto\x12\x31\n\x0boption_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xeb\x04\n\x1eResolvedGraphElementTableProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12\x31\n\ninput_scan\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12/\n\x08key_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12L\n\x15source_node_reference\x18\x05 \x01(\x0b\x32-.zetasql.ResolvedGraphNodeTableReferenceProto\x12J\n\x13\x64\x65st_node_reference\x18\x06 \x01(\x0b\x32-.zetasql.ResolvedGraphNodeTableReferenceProto\x12\x17\n\x0flabel_name_list\x18\x07 \x03(\t\x12O\n\x18property_definition_list\x18\x08 \x03(\x0b\x32-.zetasql.ResolvedGraphPropertyDefinitionProto\x12K\n\rdynamic_label\x18\t \x01(\x0b\x32\x34.zetasql.ResolvedGraphDynamicLabelSpecificationProto\x12U\n\x12\x64ynamic_properties\x18\n \x01(\x0b\x32\x39.zetasql.ResolvedGraphDynamicPropertiesSpecificationProto\"\xf3\x01\n$ResolvedGraphNodeTableReferenceProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x1d\n\x15node_table_identifier\x18\x02 \x01(\t\x12=\n\x16\x65\x64ge_table_column_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12=\n\x16node_table_column_list\x18\x04 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xba\x01\n\x1eResolvedGraphElementLabelProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12&\n\x1eproperty_declaration_name_list\x18\x03 \x03(\t\x12\x32\n\x0coptions_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x87\x01\n%ResolvedGraphPropertyDeclarationProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\"\xe7\x01\n$ResolvedGraphPropertyDefinitionProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x0b\n\x03sql\x18\x03 \x01(\t\x12!\n\x19property_declaration_name\x18\x04 \x01(\t\x12\x32\n\x0coptions_list\x18\x05 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\x90\x01\n+ResolvedGraphDynamicLabelSpecificationProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x31\n\nlabel_expr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\x98\x01\n0ResolvedGraphDynamicPropertiesSpecificationProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x34\n\rproperty_expr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xc0\x01\n\x1d\x41nyResolvedGraphScanBaseProto\x12\x44\n\x18resolved_graph_scan_node\x18\xe5\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedGraphScanProtoH\x00\x12Q\n\x1fresolved_graph_linear_scan_node\x18\xf7\x01 \x01(\x0b\x32%.zetasql.ResolvedGraphLinearScanProtoH\x00\x42\x06\n\x04node\"H\n\x1aResolvedGraphScanBaseProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"G\n\x19ResolvedGraphRefScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"\x85\x01\n\x1cResolvedGraphLinearScanProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ResolvedGraphScanBaseProto\x12\x30\n\tscan_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\xfc\x01\n\x1bResolvedGraphTableScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x36\n\x0eproperty_graph\x18\x02 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12:\n\ninput_scan\x18\x03 \x01(\x0b\x32&.zetasql.AnyResolvedGraphScanBaseProto\x12=\n\x0fshape_expr_list\x18\x04 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\"\xf7\x01\n\x1aResolvedGraphCallScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12/\n\x08subquery\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x31\n\ninput_scan\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x37\n\x0eparameter_list\x18\x05 \x03(\x0b\x32\x1f.zetasql.ResolvedColumnRefProto\"\x84\x02\n\x16ResolvedGraphScanProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ResolvedGraphScanBaseProto\x12<\n\x0finput_scan_list\x18\x02 \x03(\x0b\x32#.zetasql.ResolvedGraphPathScanProto\x12\x32\n\x0b\x66ilter_expr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\ninput_scan\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x10\n\x08optional\x18\x05 \x01(\x08\"\xc1\x01\n\'ResolvedGraphPathPatternQuantifierProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x32\n\x0blower_bound\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x32\n\x0bupper_bound\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xd7\x01\n\"ResolvedGraphPathSearchPrefixProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12N\n\x04type\x18\x02 \x01(\x0e\x32@.zetasql.ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType\x12\x31\n\npath_count\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xd2\x01\n!AnyResolvedGraphPathScanBaseProto\x12V\n resolved_graph_element_scan_node\x18\xd7\x01 \x01(\x0b\x32).zetasql.AnyResolvedGraphElementScanProtoH\x00\x12M\n\x1dresolved_graph_path_scan_node\x18\xdc\x01 \x01(\x0b\x32#.zetasql.ResolvedGraphPathScanProtoH\x00\x42\x06\n\x04node\"L\n\x1eResolvedGraphPathScanBaseProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"\xc8\x01\n AnyResolvedGraphElementScanProto\x12M\n\x1dresolved_graph_node_scan_node\x18\xd1\x01 \x01(\x0b\x32#.zetasql.ResolvedGraphNodeScanProtoH\x00\x12M\n\x1dresolved_graph_edge_scan_node\x18\xd8\x01 \x01(\x0b\x32#.zetasql.ResolvedGraphEdgeScanProtoH\x00\x42\x06\n\x04node\"\x90\x02\n\x1dResolvedGraphElementScanProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedGraphPathScanBaseProto\x12\x32\n\x0b\x66ilter_expr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12;\n\nlabel_expr\x18\x03 \x01(\x0b\x32\'.zetasql.AnyResolvedGraphLabelExprProto\x12\x45\n\x19target_element_table_list\x18\x04 \x03(\x0b\x32\".zetasql.GraphElementTableRefProto\"T\n\x1aResolvedGraphNodeScanProto\x12\x36\n\x06parent\x18\x01 \x01(\x0b\x32&.zetasql.ResolvedGraphElementScanProto\"\xba\x02\n\x1aResolvedGraphEdgeScanProto\x12\x36\n\x06parent\x18\x01 \x01(\x0b\x32&.zetasql.ResolvedGraphElementScanProto\x12H\n\x0borientation\x18\x02 \x01(\x0e\x32\x33.zetasql.ResolvedGraphEdgeScanEnums.EdgeOrientation\x12\x33\n\rlhs_hint_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x33\n\rrhs_hint_list\x18\x04 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x30\n\tcost_expr\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xf2\x01\n$ResolvedGraphGetElementPropertyProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12;\n\x08property\x18\x03 \x01(\x0b\x32).zetasql.GraphPropertyDeclarationRefProto\x12\x34\n\rproperty_name\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xa4\x02\n\x1e\x41nyResolvedGraphLabelExprProto\x12X\n#resolved_graph_label_nary_expr_node\x18\xd4\x01 \x01(\x0b\x32(.zetasql.ResolvedGraphLabelNaryExprProtoH\x00\x12\x46\n\x19resolved_graph_label_node\x18\xd5\x01 \x01(\x0b\x32 .zetasql.ResolvedGraphLabelProtoH\x00\x12X\n#resolved_graph_wild_card_label_node\x18\xd6\x01 \x01(\x0b\x32(.zetasql.ResolvedGraphWildCardLabelProtoH\x00\x42\x06\n\x04node\"M\n\x1bResolvedGraphLabelExprProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\"\xdf\x01\n\x1fResolvedGraphLabelNaryExprProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ResolvedGraphLabelExprProto\x12G\n\x02op\x18\x02 \x01(\x0e\x32;.zetasql.ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType\x12=\n\x0coperand_list\x18\x03 \x03(\x0b\x32\'.zetasql.AnyResolvedGraphLabelExprProto\"\xb5\x01\n\x17ResolvedGraphLabelProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ResolvedGraphLabelExprProto\x12\x31\n\x05label\x18\x02 \x01(\x0b\x32\".zetasql.GraphElementLabelRefProto\x12\x31\n\nlabel_name\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"W\n\x1fResolvedGraphWildCardLabelProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ResolvedGraphLabelExprProto\"\xdb\x02\n#ResolvedGraphElementIdentifierProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x39\n\relement_table\x18\x02 \x01(\x0b\x32\".zetasql.GraphElementTableRefProto\x12/\n\x08key_list\x18\x03 \x03(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12L\n\x16source_node_identifier\x18\x04 \x01(\x0b\x32,.zetasql.ResolvedGraphElementIdentifierProto\x12J\n\x14\x64\x65st_node_identifier\x18\x05 \x01(\x0b\x32,.zetasql.ResolvedGraphElementIdentifierProto\"\xc0\x01\n!ResolvedGraphElementPropertyProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12>\n\x0b\x64\x65\x63laration\x18\x02 \x01(\x0b\x32).zetasql.GraphPropertyDeclarationRefProto\x12+\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xfa\x02\n\x1dResolvedGraphMakeElementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12@\n\nidentifier\x18\x02 \x01(\x0b\x32,.zetasql.ResolvedGraphElementIdentifierProto\x12\x41\n\rproperty_list\x18\x03 \x03(\x0b\x32*.zetasql.ResolvedGraphElementPropertyProto\x12\x36\n\nlabel_list\x18\x04 \x03(\x0b\x32\".zetasql.GraphElementLabelRefProto\x12\x35\n\x0e\x64ynamic_labels\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x39\n\x12\x64ynamic_properties\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xbf\x02\n\x1bResolvedArrayAggregateProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12,\n\x05\x61rray\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x34\n\x0e\x65lement_column\x18\x03 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12P\n\"pre_aggregate_computed_column_list\x18\x04 \x03(\x0b\x32$.zetasql.ResolvedComputedColumnProto\x12>\n\taggregate\x18\x05 \x01(\x0b\x32+.zetasql.ResolvedAggregateFunctionCallProto\"\xb1\x01\n#ResolvedGraphMakeArrayVariableProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12-\n\x07\x65lement\x18\x02 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12+\n\x05\x61rray\x18\x03 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\"\x8d\x01\n\x1aResolvedGraphPathModeProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12?\n\tpath_mode\x18\x02 \x01(\x0e\x32,.zetasql.ResolvedGraphPathModeEnums.PathMode\"x\n\x1aResolvedGraphPathCostProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12*\n\x0e\x63ost_supertype\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\"\xd3\x05\n\x1aResolvedGraphPathScanProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ResolvedGraphPathScanBaseProto\x12\x43\n\x0finput_scan_list\x18\x02 \x03(\x0b\x32*.zetasql.AnyResolvedGraphPathScanBaseProto\x12\x32\n\x0b\x66ilter_expr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x30\n\x04path\x18\x0b \x01(\x0b\x32\".zetasql.ResolvedColumnHolderProto\x12*\n\x04head\x18\x04 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12*\n\x04tail\x18\x05 \x01(\x0b\x32\x1c.zetasql.ResolvedColumnProto\x12\x34\n\x0epath_hint_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\x12\x44\n\nquantifier\x18\x07 \x01(\x0b\x32\x30.zetasql.ResolvedGraphPathPatternQuantifierProto\x12I\n\x13group_variable_list\x18\x08 \x03(\x0b\x32,.zetasql.ResolvedGraphMakeArrayVariableProto\x12\x36\n\tpath_mode\x18\t \x01(\x0b\x32#.zetasql.ResolvedGraphPathModeProto\x12\x42\n\rsearch_prefix\x18\n \x01(\x0b\x32+.zetasql.ResolvedGraphPathSearchPrefixProto\x12\x36\n\tpath_cost\x18\x0c \x01(\x0b\x32#.zetasql.ResolvedGraphPathCostProto\"\xcc\x01\n$ResolvedGraphIsLabeledPredicateProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12\x0e\n\x06is_not\x18\x02 \x01(\x08\x12+\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12;\n\nlabel_expr\x18\x04 \x01(\x0b\x32\'.zetasql.AnyResolvedGraphLabelExprProto\"\x83\x02\n\x17ResolvedUndropStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x1a\n\x12schema_object_kind\x18\x02 \x01(\t\x12\x18\n\x10is_if_not_exists\x18\x03 \x01(\x08\x12\x11\n\tname_path\x18\x04 \x03(\t\x12;\n\x14\x66or_system_time_expr\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x31\n\x0boption_list\x18\x06 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"\xba\x02\n\x1fResolvedIdentityColumnInfoProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x35\n\x10start_with_value\x18\x02 \x01(\x0b\x32\x1b.zetasql.ValueWithTypeProto\x12\x37\n\x12increment_by_value\x18\x03 \x01(\x0b\x32\x1b.zetasql.ValueWithTypeProto\x12.\n\tmax_value\x18\x04 \x01(\x0b\x32\x1b.zetasql.ValueWithTypeProto\x12.\n\tmin_value\x18\x05 \x01(\x0b\x32\x1b.zetasql.ValueWithTypeProto\x12\x17\n\x0f\x63ycling_enabled\x18\x06 \x01(\x08\"\xb7\x01\n\x19ResolvedDescribeScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12;\n\rdescribe_expr\x18\x03 \x01(\x0b\x32$.zetasql.ResolvedComputedColumnProto\"\x97\x01\n\x1fResolvedStaticDescribeScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x15\n\rdescribe_text\x18\x03 \x01(\t\"\xda\x01\n\x17ResolvedAssertScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x30\n\tcondition\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12.\n\x07message\x18\x04 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\"\xe8\x01\n\x14ResolvedLogScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x36\n\x0bsubpipeline\x18\x03 \x01(\x0b\x32!.zetasql.ResolvedSubpipelineProto\x12\x39\n\routput_schema\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedOutputSchemaProto\"\xc7\x01\n\x17ResolvedPipeIfScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12\x15\n\rselected_case\x18\x03 \x01(\x03\x12\x36\n\x0cif_case_list\x18\x04 \x03(\x0b\x32 .zetasql.ResolvedPipeIfCaseProto\"\xcc\x01\n\x17ResolvedPipeIfCaseProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x30\n\tcondition\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\x17\n\x0fsubpipeline_sql\x18\x03 \x01(\t\x12\x36\n\x0bsubpipeline\x18\x04 \x01(\x0b\x32!.zetasql.ResolvedSubpipelineProto\"\xc7\x01\n\x19ResolvedPipeForkScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12K\n\x10subpipeline_list\x18\x03 \x03(\x0b\x32\x31.zetasql.ResolvedGeneralizedQuerySubpipelineProto\"\xc6\x01\n\x18ResolvedPipeTeeScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\x12K\n\x10subpipeline_list\x18\x03 \x03(\x0b\x32\x31.zetasql.ResolvedGeneralizedQuerySubpipelineProto\"\x8d\x01\n\x1fResolvedPipeExportDataScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12>\n\x10\x65xport_data_stmt\x18\x02 \x01(\x0b\x32$.zetasql.ResolvedExportDataStmtProto\"\xa2\x01\n ResolvedPipeCreateTableScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12R\n\x1b\x63reate_table_as_select_stmt\x18\x02 \x01(\x0b\x32-.zetasql.ResolvedCreateTableAsSelectStmtProto\"\x80\x01\n\x1bResolvedPipeInsertScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x35\n\x0binsert_stmt\x18\x02 \x01(\x0b\x32 .zetasql.ResolvedInsertStmtProto\"w\n\x18ResolvedSubpipelineProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"O\n!ResolvedSubpipelineInputScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\"\xf7\x01\n\x1cResolvedSubpipelineStmtProto\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1f.zetasql.ResolvedStatementProto\x12\x33\n\ntable_scan\x18\x02 \x01(\x0b\x32\x1f.zetasql.ResolvedTableScanProto\x12\x36\n\x0bsubpipeline\x18\x03 \x01(\x0b\x32!.zetasql.ResolvedSubpipelineProto\x12\x39\n\routput_schema\x18\x04 \x01(\x0b\x32\".zetasql.ResolvedOutputSchemaProto\"\xcd\x01\n(ResolvedGeneralizedQuerySubpipelineProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x36\n\x0bsubpipeline\x18\x02 \x01(\x0b\x32!.zetasql.ResolvedSubpipelineProto\x12\x39\n\routput_schema\x18\x03 \x01(\x0b\x32\".zetasql.ResolvedOutputSchemaProto\"y\n\x18ResolvedBarrierScanProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedScanProto\x12\x31\n\ninput_scan\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedScanProto\"\x8d\x01\n!ResolvedCreateConnectionStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"Y\n ResolvedAlterConnectionStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProto\"\x8a\x01\n\x15ResolvedLockModeProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12\x41\n\x08strength\x18\x02 \x01(\x0e\x32/.zetasql.ResolvedLockModeEnums.LockStrengthType\"\xfb\x01\n\x1cResolvedUpdateFieldItemProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ResolvedArgumentProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12:\n\x10proto_field_path\x18\x03 \x03(\x0b\x32 .zetasql.FieldDescriptorRefProto\x12\x42\n\toperation\x18\x04 \x01(\x0e\x32/.zetasql.ResolvedUpdateFieldItemEnums.Operation\"\xcf\x01\n\x1eResolvedUpdateConstructorProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ResolvedExprProto\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProto\x12\r\n\x05\x61lias\x18\x03 \x01(\t\x12\x45\n\x16update_field_item_list\x18\x04 \x03(\x0b\x32%.zetasql.ResolvedUpdateFieldItemProto\"\x8b\x01\n\x1fResolvedCreateSequenceStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedCreateStatementProto\x12\x31\n\x0boption_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ResolvedOptionProto\"W\n\x1eResolvedAlterSequenceStmtProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ResolvedAlterObjectStmtProtoB,\n\x12\x63om.google.zetasqlB\x12ZetaSQLResolvedASTH\x02P\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.resolved_ast_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\022ZetaSQLResolvedASTH\002P\001'
  _globals['_ANYRESOLVEDNODEPROTO']._serialized_start=351
  _globals['_ANYRESOLVEDNODEPROTO']._serialized_end=643
  _globals['_ANYRESOLVEDARGUMENTPROTO']._serialized_start=646
  _globals['_ANYRESOLVEDARGUMENTPROTO']._serialized_end=7512
  _globals['_RESOLVEDARGUMENTPROTO']._serialized_start=7514
  _globals['_RESOLVEDARGUMENTPROTO']._serialized_end=7581
  _globals['_ANYRESOLVEDEXPRPROTO']._serialized_start=7584
  _globals['_ANYRESOLVEDEXPRPROTO']._serialized_end=9831
  _globals['_RESOLVEDEXPRPROTO']._serialized_start=9834
  _globals['_RESOLVEDEXPRPROTO']._serialized_end=9989
  _globals['_RESOLVEDLITERALPROTO']._serialized_start=9992
  _globals['_RESOLVEDLITERALPROTO']._serialized_end=10192
  _globals['_RESOLVEDPARAMETERPROTO']._serialized_start=10194
  _globals['_RESOLVEDPARAMETERPROTO']._serialized_end=10314
  _globals['_RESOLVEDEXPRESSIONCOLUMNPROTO']._serialized_start=10316
  _globals['_RESOLVEDEXPRESSIONCOLUMNPROTO']._serialized_end=10405
  _globals['_RESOLVEDCATALOGCOLUMNREFPROTO']._serialized_start=10407
  _globals['_RESOLVEDCATALOGCOLUMNREFPROTO']._serialized_end=10523
  _globals['_RESOLVEDCOLUMNREFPROTO']._serialized_start=10526
  _globals['_RESOLVEDCOLUMNREFPROTO']._serialized_end=10663
  _globals['_RESOLVEDGROUPINGSETMULTICOLUMNPROTO']._serialized_start=10666
  _globals['_RESOLVEDGROUPINGSETMULTICOLUMNPROTO']._serialized_end=10805
  _globals['_RESOLVEDCONSTANTPROTO']._serialized_start=10807
  _globals['_RESOLVEDCONSTANTPROTO']._serialized_end=10919
  _globals['_RESOLVEDSYSTEMVARIABLEPROTO']._serialized_start=10921
  _globals['_RESOLVEDSYSTEMVARIABLEPROTO']._serialized_end=11013
  _globals['_RESOLVEDINLINELAMBDAPROTO']._serialized_start=11016
  _globals['_RESOLVEDINLINELAMBDAPROTO']._serialized_end=11246
  _globals['_RESOLVEDSEQUENCEPROTO']._serialized_start=11248
  _globals['_RESOLVEDSEQUENCEPROTO']._serialized_end=11364
  _globals['_RESOLVEDFILTERFIELDARGPROTO']._serialized_start=11367
  _globals['_RESOLVEDFILTERFIELDARGPROTO']._serialized_end=11526
  _globals['_RESOLVEDFILTERFIELDPROTO']._serialized_start=11529
  _globals['_RESOLVEDFILTERFIELDPROTO']._serialized_end=11752
  _globals['_ANYRESOLVEDFUNCTIONCALLBASEPROTO']._serialized_start=11755
  _globals['_ANYRESOLVEDFUNCTIONCALLBASEPROTO']._serialized_end=11979
  _globals['_RESOLVEDFUNCTIONCALLBASEPROTO']._serialized_start=11982
  _globals['_RESOLVEDFUNCTIONCALLBASEPROTO']._serialized_end=12455
  _globals['_RESOLVEDFUNCTIONCALLPROTO']._serialized_start=12458
  _globals['_RESOLVEDFUNCTIONCALLPROTO']._serialized_end=12609
  _globals['_ANYRESOLVEDNONSCALARFUNCTIONCALLBASEPROTO']._serialized_start=12612
  _globals['_ANYRESOLVEDNONSCALARFUNCTIONCALLBASEPROTO']._serialized_end=12849
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEPROTO']._serialized_start=12852
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEPROTO']._serialized_end=13119
  _globals['_RESOLVEDAGGREGATEFUNCTIONCALLPROTO']._serialized_start=13122
  _globals['_RESOLVEDAGGREGATEFUNCTIONCALLPROTO']._serialized_end=13721
  _globals['_RESOLVEDANALYTICFUNCTIONCALLPROTO']._serialized_start=13724
  _globals['_RESOLVEDANALYTICFUNCTIONCALLPROTO']._serialized_end=13881
  _globals['_RESOLVEDEXTENDEDCASTELEMENTPROTO']._serialized_start=13884
  _globals['_RESOLVEDEXTENDEDCASTELEMENTPROTO']._serialized_end=14087
  _globals['_RESOLVEDEXTENDEDCASTPROTO']._serialized_start=14090
  _globals['_RESOLVEDEXTENDEDCASTPROTO']._serialized_end=14230
  _globals['_RESOLVEDCASTPROTO']._serialized_start=14233
  _globals['_RESOLVEDCASTPROTO']._serialized_end=14580
  _globals['_RESOLVEDMAKESTRUCTPROTO']._serialized_start=14582
  _globals['_RESOLVEDMAKESTRUCTPROTO']._serialized_end=14702
  _globals['_RESOLVEDMAKEPROTOPROTO']._serialized_start=14704
  _globals['_RESOLVEDMAKEPROTOPROTO']._serialized_end=14830
  _globals['_RESOLVEDMAKEPROTOFIELDPROTO']._serialized_start=14833
  _globals['_RESOLVEDMAKEPROTOFIELDPROTO']._serialized_end=15060
  _globals['_RESOLVEDGETSTRUCTFIELDPROTO']._serialized_start=15063
  _globals['_RESOLVEDGETSTRUCTFIELDPROTO']._serialized_end=15234
  _globals['_RESOLVEDGETPROTOFIELDPROTO']._serialized_start=15237
  _globals['_RESOLVEDGETPROTOFIELDPROTO']._serialized_end=15573
  _globals['_RESOLVEDGETJSONFIELDPROTO']._serialized_start=15576
  _globals['_RESOLVEDGETJSONFIELDPROTO']._serialized_end=15712
  _globals['_RESOLVEDGETROWFIELDPROTO']._serialized_start=15715
  _globals['_RESOLVEDGETROWFIELDPROTO']._serialized_end=15871
  _globals['_RESOLVEDFLATTENPROTO']._serialized_start=15874
  _globals['_RESOLVEDFLATTENPROTO']._serialized_end=16040
  _globals['_RESOLVEDFLATTENEDARGPROTO']._serialized_start=16042
  _globals['_RESOLVEDFLATTENEDARGPROTO']._serialized_end=16113
  _globals['_RESOLVEDREPLACEFIELDITEMPROTO']._serialized_start=16116
  _globals['_RESOLVEDREPLACEFIELDITEMPROTO']._serialized_end=16327
  _globals['_RESOLVEDREPLACEFIELDPROTO']._serialized_start=16330
  _globals['_RESOLVEDREPLACEFIELDPROTO']._serialized_end=16519
  _globals['_RESOLVEDGETPROTOONEOFPROTO']._serialized_start=16522
  _globals['_RESOLVEDGETPROTOONEOFPROTO']._serialized_end=16699
  _globals['_RESOLVEDSUBQUERYEXPRPROTO']._serialized_start=16702
  _globals['_RESOLVEDSUBQUERYEXPRPROTO']._serialized_end=17103
  _globals['_RESOLVEDWITHEXPRPROTO']._serialized_start=17106
  _globals['_RESOLVEDWITHEXPRPROTO']._serialized_end=17281
  _globals['_ANYRESOLVEDSCANPROTO']._serialized_start=17284
  _globals['_ANYRESOLVEDSCANPROTO']._serialized_end=20531
  _globals['_RESOLVEDSCANPROTO']._serialized_start=20534
  _globals['_RESOLVEDSCANPROTO']._serialized_end=20738
  _globals['_RESOLVEDEXECUTEASROLESCANPROTO']._serialized_start=20741
  _globals['_RESOLVEDEXECUTEASROLESCANPROTO']._serialized_end=20991
  _globals['_RESOLVEDMODELPROTO']._serialized_start=20993
  _globals['_RESOLVEDMODELPROTO']._serialized_end=21100
  _globals['_RESOLVEDCONNECTIONPROTO']._serialized_start=21102
  _globals['_RESOLVEDCONNECTIONPROTO']._serialized_end=21224
  _globals['_RESOLVEDDESCRIPTORPROTO']._serialized_start=21227
  _globals['_RESOLVEDDESCRIPTORPROTO']._serialized_end=21399
  _globals['_RESOLVEDSINGLEROWSCANPROTO']._serialized_start=21401
  _globals['_RESOLVEDSINGLEROWSCANPROTO']._serialized_end=21473
  _globals['_RESOLVEDUNSETARGUMENTSCANPROTO']._serialized_start=21475
  _globals['_RESOLVEDUNSETARGUMENTSCANPROTO']._serialized_end=21551
  _globals['_RESOLVEDTABLESCANPROTO']._serialized_start=21554
  _globals['_RESOLVEDTABLESCANPROTO']._serialized_end=21893
  _globals['_RESOLVEDJOINSCANPROTO']._serialized_start=21896
  _globals['_RESOLVEDJOINSCANPROTO']._serialized_end=22270
  _globals['_RESOLVEDARRAYSCANPROTO']._serialized_start=22273
  _globals['_RESOLVEDARRAYSCANPROTO']._serialized_end=22695
  _globals['_RESOLVEDCOLUMNHOLDERPROTO']._serialized_start=22697
  _globals['_RESOLVEDCOLUMNHOLDERPROTO']._serialized_end=22818
  _globals['_RESOLVEDFILTERSCANPROTO']._serialized_start=22821
  _globals['_RESOLVEDFILTERSCANPROTO']._serialized_end=22993
  _globals['_RESOLVEDGROUPINGCALLPROTO']._serialized_start=22996
  _globals['_RESOLVEDGROUPINGCALLPROTO']._serialized_end=23182
  _globals['_ANYRESOLVEDGROUPINGSETBASEPROTO']._serialized_start=23185
  _globals['_ANYRESOLVEDGROUPINGSETBASEPROTO']._serialized_end=23593
  _globals['_RESOLVEDGROUPINGSETBASEPROTO']._serialized_start=23595
  _globals['_RESOLVEDGROUPINGSETBASEPROTO']._serialized_end=23673
  _globals['_RESOLVEDGROUPINGSETLISTPROTO']._serialized_start=23676
  _globals['_RESOLVEDGROUPINGSETLISTPROTO']._serialized_end=23822
  _globals['_RESOLVEDGROUPINGSETPRODUCTPROTO']._serialized_start=23825
  _globals['_RESOLVEDGROUPINGSETPRODUCTPROTO']._serialized_end=23975
  _globals['_RESOLVEDGROUPINGSETPROTO']._serialized_start=23978
  _globals['_RESOLVEDGROUPINGSETPROTO']._serialized_end=24122
  _globals['_RESOLVEDROLLUPPROTO']._serialized_start=24125
  _globals['_RESOLVEDROLLUPPROTO']._serialized_end=24275
  _globals['_RESOLVEDCUBEPROTO']._serialized_start=24278
  _globals['_RESOLVEDCUBEPROTO']._serialized_end=24424
  _globals['_ANYRESOLVEDAGGREGATESCANBASEPROTO']._serialized_start=24427
  _globals['_ANYRESOLVEDAGGREGATESCANBASEPROTO']._serialized_end=24883
  _globals['_RESOLVEDAGGREGATESCANBASEPROTO']._serialized_start=24886
  _globals['_RESOLVEDAGGREGATESCANBASEPROTO']._serialized_end=25394
  _globals['_RESOLVEDAGGREGATESCANPROTO']._serialized_start=25396
  _globals['_RESOLVEDAGGREGATESCANPROTO']._serialized_end=25481
  _globals['_RESOLVEDANONYMIZEDAGGREGATESCANPROTO']._serialized_start=25484
  _globals['_RESOLVEDANONYMIZEDAGGREGATESCANPROTO']._serialized_end=25701
  _globals['_RESOLVEDDIFFERENTIALPRIVACYAGGREGATESCANPROTO']._serialized_start=25704
  _globals['_RESOLVEDDIFFERENTIALPRIVACYAGGREGATESCANPROTO']._serialized_end=25930
  _globals['_RESOLVEDAGGREGATIONTHRESHOLDAGGREGATESCANPROTO']._serialized_start=25933
  _globals['_RESOLVEDAGGREGATIONTHRESHOLDAGGREGATESCANPROTO']._serialized_end=26089
  _globals['_RESOLVEDSETOPERATIONITEMPROTO']._serialized_start=26092
  _globals['_RESOLVEDSETOPERATIONITEMPROTO']._serialized_end=26274
  _globals['_RESOLVEDSETOPERATIONSCANPROTO']._serialized_start=26277
  _globals['_RESOLVEDSETOPERATIONSCANPROTO']._serialized_end=26693
  _globals['_RESOLVEDORDERBYSCANPROTO']._serialized_start=26696
  _globals['_RESOLVEDORDERBYSCANPROTO']._serialized_end=26880
  _globals['_RESOLVEDLIMITOFFSETSCANPROTO']._serialized_start=26883
  _globals['_RESOLVEDLIMITOFFSETSCANPROTO']._serialized_end=27101
  _globals['_RESOLVEDWITHREFSCANPROTO']._serialized_start=27103
  _globals['_RESOLVEDWITHREFSCANPROTO']._serialized_end=27198
  _globals['_RESOLVEDANALYTICSCANPROTO']._serialized_start=27201
  _globals['_RESOLVEDANALYTICSCANPROTO']._serialized_end=27397
  _globals['_RESOLVEDSAMPLESCANPROTO']._serialized_start=27400
  _globals['_RESOLVEDSAMPLESCANPROTO']._serialized_end=27817
  _globals['_ANYRESOLVEDCOMPUTEDCOLUMNBASEPROTO']._serialized_start=27820
  _globals['_ANYRESOLVEDCOMPUTEDCOLUMNBASEPROTO']._serialized_end=27956
  _globals['_RESOLVEDCOMPUTEDCOLUMNBASEPROTO']._serialized_start=27958
  _globals['_RESOLVEDCOMPUTEDCOLUMNBASEPROTO']._serialized_end=28039
  _globals['_ANYRESOLVEDCOMPUTEDCOLUMNIMPLPROTO']._serialized_start=28042
  _globals['_ANYRESOLVEDCOMPUTEDCOLUMNIMPLPROTO']._serialized_end=28262
  _globals['_RESOLVEDCOMPUTEDCOLUMNIMPLPROTO']._serialized_start=28264
  _globals['_RESOLVEDCOMPUTEDCOLUMNIMPLPROTO']._serialized_end=28355
  _globals['_RESOLVEDCOMPUTEDCOLUMNPROTO']._serialized_start=28358
  _globals['_RESOLVEDCOMPUTEDCOLUMNPROTO']._serialized_end=28536
  _globals['_RESOLVEDDEFERREDCOMPUTEDCOLUMNPROTO']._serialized_start=28539
  _globals['_RESOLVEDDEFERREDCOMPUTEDCOLUMNPROTO']._serialized_end=28783
  _globals['_RESOLVEDORDERBYITEMPROTO']._serialized_start=28786
  _globals['_RESOLVEDORDERBYITEMPROTO']._serialized_end=29112
  _globals['_RESOLVEDCOLUMNANNOTATIONSPROTO']._serialized_start=29115
  _globals['_RESOLVEDCOLUMNANNOTATIONSPROTO']._serialized_end=29435
  _globals['_RESOLVEDGENERATEDCOLUMNINFOPROTO']._serialized_start=29438
  _globals['_RESOLVEDGENERATEDCOLUMNINFOPROTO']._serialized_end=29799
  _globals['_RESOLVEDCOLUMNDEFAULTVALUEPROTO']._serialized_start=29802
  _globals['_RESOLVEDCOLUMNDEFAULTVALUEPROTO']._serialized_end=29947
  _globals['_RESOLVEDCOLUMNDEFINITIONPROTO']._serialized_start=29950
  _globals['_RESOLVEDCOLUMNDEFINITIONPROTO']._serialized_end=30343
  _globals['_ANYRESOLVEDCONSTRAINTPROTO']._serialized_start=30346
  _globals['_ANYRESOLVEDCONSTRAINTPROTO']._serialized_end=30605
  _globals['_RESOLVEDCONSTRAINTPROTO']._serialized_start=30607
  _globals['_RESOLVEDCONSTRAINTPROTO']._serialized_end=30680
  _globals['_RESOLVEDPRIMARYKEYPROTO']._serialized_start=30683
  _globals['_RESOLVEDPRIMARYKEYPROTO']._serialized_end=30908
  _globals['_RESOLVEDFOREIGNKEYPROTO']._serialized_start=30911
  _globals['_RESOLVEDFOREIGNKEYPROTO']._serialized_end=31452
  _globals['_RESOLVEDCHECKCONSTRAINTPROTO']._serialized_start=31455
  _globals['_RESOLVEDCHECKCONSTRAINTPROTO']._serialized_end=31680
  _globals['_RESOLVEDOUTPUTCOLUMNPROTO']._serialized_start=31683
  _globals['_RESOLVEDOUTPUTCOLUMNPROTO']._serialized_end=31818
  _globals['_RESOLVEDOUTPUTSCHEMAPROTO']._serialized_start=31821
  _globals['_RESOLVEDOUTPUTSCHEMAPROTO']._serialized_end=31984
  _globals['_RESOLVEDPROJECTSCANPROTO']._serialized_start=31987
  _globals['_RESOLVEDPROJECTSCANPROTO']._serialized_end=32165
  _globals['_RESOLVEDTVFSCANPROTO']._serialized_start=32168
  _globals['_RESOLVEDTVFSCANPROTO']._serialized_end=32503
  _globals['_RESOLVEDGROUPROWSSCANPROTO']._serialized_start=32506
  _globals['_RESOLVEDGROUPROWSSCANPROTO']._serialized_end=32658
  _globals['_RESOLVEDFUNCTIONARGUMENTPROTO']._serialized_start=32661
  _globals['_RESOLVEDFUNCTIONARGUMENTPROTO']._serialized_end=33226
  _globals['_ANYRESOLVEDSTATEMENTPROTO']._serialized_start=33229
  _globals['_ANYRESOLVEDSTATEMENTPROTO']._serialized_end=37350
  _globals['_RESOLVEDSTATEMENTPROTO']._serialized_start=37352
  _globals['_RESOLVEDSTATEMENTPROTO']._serialized_end=37469
  _globals['_RESOLVEDEXPLAINSTMTPROTO']._serialized_start=37472
  _globals['_RESOLVEDEXPLAINSTMTPROTO']._serialized_end=37602
  _globals['_RESOLVEDSTATEMENTWITHPIPEOPERATORSSTMTPROTO']._serialized_start=37605
  _globals['_RESOLVEDSTATEMENTWITHPIPEOPERATORSSTMTPROTO']._serialized_end=37786
  _globals['_RESOLVEDQUERYSTMTPROTO']._serialized_start=37789
  _globals['_RESOLVEDQUERYSTMTPROTO']._serialized_end=37996
  _globals['_RESOLVEDGENERALIZEDQUERYSTMTPROTO']._serialized_start=37999
  _globals['_RESOLVEDGENERALIZEDQUERYSTMTPROTO']._serialized_end=38188
  _globals['_RESOLVEDMULTISTMTPROTO']._serialized_start=38191
  _globals['_RESOLVEDMULTISTMTPROTO']._serialized_end=38324
  _globals['_RESOLVEDCREATEWITHENTRYSTMTPROTO']._serialized_start=38327
  _globals['_RESOLVEDCREATEWITHENTRYSTMTPROTO']._serialized_end=38463
  _globals['_RESOLVEDCREATEDATABASESTMTPROTO']._serialized_start=38466
  _globals['_RESOLVEDCREATEDATABASESTMTPROTO']._serialized_end=38618
  _globals['_ANYRESOLVEDCREATESTATEMENTPROTO']._serialized_start=38621
  _globals['_ANYRESOLVEDCREATESTATEMENTPROTO']._serialized_end=40046
  _globals['_RESOLVEDCREATESTATEMENTPROTO']._serialized_start=40049
  _globals['_RESOLVEDCREATESTATEMENTPROTO']._serialized_end=40291
  _globals['_RESOLVEDINDEXITEMPROTO']._serialized_start=40294
  _globals['_RESOLVEDINDEXITEMPROTO']._serialized_end=40490
  _globals['_RESOLVEDUNNESTITEMPROTO']._serialized_start=40493
  _globals['_RESOLVEDUNNESTITEMPROTO']._serialized_end=40736
  _globals['_RESOLVEDCREATEINDEXSTMTPROTO']._serialized_start=40739
  _globals['_RESOLVEDCREATEINDEXSTMTPROTO']._serialized_end=41353
  _globals['_ANYRESOLVEDCREATESCHEMASTMTBASEPROTO']._serialized_start=41356
  _globals['_ANYRESOLVEDCREATESCHEMASTMTBASEPROTO']._serialized_end=41589
  _globals['_RESOLVEDCREATESCHEMASTMTBASEPROTO']._serialized_start=41592
  _globals['_RESOLVEDCREATESCHEMASTMTBASEPROTO']._serialized_end=41733
  _globals['_RESOLVEDCREATESCHEMASTMTPROTO']._serialized_start=41736
  _globals['_RESOLVEDCREATESCHEMASTMTPROTO']._serialized_end=41882
  _globals['_RESOLVEDCREATEEXTERNALSCHEMASTMTPROTO']._serialized_start=41885
  _globals['_RESOLVEDCREATEEXTERNALSCHEMASTMTPROTO']._serialized_end=42038
  _globals['_ANYRESOLVEDCREATETABLESTMTBASEPROTO']._serialized_start=42041
  _globals['_ANYRESOLVEDCREATETABLESTMTBASEPROTO']._serialized_end=42367
  _globals['_RESOLVEDCREATETABLESTMTBASEPROTO']._serialized_start=42370
  _globals['_RESOLVEDCREATETABLESTMTBASEPROTO']._serialized_end=43002
  _globals['_RESOLVEDCREATETABLESTMTPROTO']._serialized_start=43005
  _globals['_RESOLVEDCREATETABLESTMTPROTO']._serialized_end=43309
  _globals['_RESOLVEDCREATETABLEASSELECTSTMTPROTO']._serialized_start=43312
  _globals['_RESOLVEDCREATETABLEASSELECTSTMTPROTO']._serialized_end=43633
  _globals['_RESOLVEDCREATEMODELALIASEDQUERYPROTO']._serialized_start=43636
  _globals['_RESOLVEDCREATEMODELALIASEDQUERYPROTO']._serialized_end=43847
  _globals['_RESOLVEDCREATEMODELSTMTPROTO']._serialized_start=43850
  _globals['_RESOLVEDCREATEMODELSTMTPROTO']._serialized_end=44707
  _globals['_ANYRESOLVEDCREATEVIEWBASEPROTO']._serialized_start=44710
  _globals['_ANYRESOLVEDCREATEVIEWBASEPROTO']._serialized_end=45029
  _globals['_RESOLVEDCREATEVIEWBASEPROTO']._serialized_start=45032
  _globals['_RESOLVEDCREATEVIEWBASEPROTO']._serialized_end=45508
  _globals['_RESOLVEDCREATEVIEWSTMTPROTO']._serialized_start=45510
  _globals['_RESOLVEDCREATEVIEWSTMTPROTO']._serialized_end=45593
  _globals['_RESOLVEDWITHPARTITIONCOLUMNSPROTO']._serialized_start=45596
  _globals['_RESOLVEDWITHPARTITIONCOLUMNSPROTO']._serialized_end=45751
  _globals['_RESOLVEDCREATESNAPSHOTTABLESTMTPROTO']._serialized_start=45754
  _globals['_RESOLVEDCREATESNAPSHOTTABLESTMTPROTO']._serialized_end=45949
  _globals['_RESOLVEDCREATEEXTERNALTABLESTMTPROTO']._serialized_start=45952
  _globals['_RESOLVEDCREATEEXTERNALTABLESTMTPROTO']._serialized_end=46125
  _globals['_RESOLVEDEXPORTMODELSTMTPROTO']._serialized_start=46128
  _globals['_RESOLVEDEXPORTMODELSTMTPROTO']._serialized_end=46337
  _globals['_RESOLVEDEXPORTDATASTMTPROTO']._serialized_start=46340
  _globals['_RESOLVEDEXPORTDATASTMTPROTO']._serialized_end=46657
  _globals['_RESOLVEDEXPORTMETADATASTMTPROTO']._serialized_start=46660
  _globals['_RESOLVEDEXPORTMETADATASTMTPROTO']._serialized_end=46894
  _globals['_RESOLVEDDEFINETABLESTMTPROTO']._serialized_start=46897
  _globals['_RESOLVEDDEFINETABLESTMTPROTO']._serialized_end=47046
  _globals['_RESOLVEDDESCRIBESTMTPROTO']._serialized_start=47049
  _globals['_RESOLVEDDESCRIBESTMTPROTO']._serialized_end=47189
  _globals['_RESOLVEDSHOWSTMTPROTO']._serialized_start=47192
  _globals['_RESOLVEDSHOWSTMTPROTO']._serialized_end=47353
  _globals['_RESOLVEDBEGINSTMTPROTO']._serialized_start=47356
  _globals['_RESOLVEDBEGINSTMTPROTO']._serialized_end=47531
  _globals['_RESOLVEDSETTRANSACTIONSTMTPROTO']._serialized_start=47534
  _globals['_RESOLVEDSETTRANSACTIONSTMTPROTO']._serialized_end=47718
  _globals['_RESOLVEDCOMMITSTMTPROTO']._serialized_start=47720
  _globals['_RESOLVEDCOMMITSTMTPROTO']._serialized_end=47794
  _globals['_RESOLVEDROLLBACKSTMTPROTO']._serialized_start=47796
  _globals['_RESOLVEDROLLBACKSTMTPROTO']._serialized_end=47872
  _globals['_RESOLVEDSTARTBATCHSTMTPROTO']._serialized_start=47874
  _globals['_RESOLVEDSTARTBATCHSTMTPROTO']._serialized_end=47972
  _globals['_RESOLVEDRUNBATCHSTMTPROTO']._serialized_start=47974
  _globals['_RESOLVEDRUNBATCHSTMTPROTO']._serialized_end=48050
  _globals['_RESOLVEDABORTBATCHSTMTPROTO']._serialized_start=48052
  _globals['_RESOLVEDABORTBATCHSTMTPROTO']._serialized_end=48130
  _globals['_RESOLVEDDROPSTMTPROTO']._serialized_start=48133
  _globals['_RESOLVEDDROPSTMTPROTO']._serialized_end=48327
  _globals['_RESOLVEDDROPMATERIALIZEDVIEWSTMTPROTO']._serialized_start=48330
  _globals['_RESOLVEDDROPMATERIALIZEDVIEWSTMTPROTO']._serialized_end=48459
  _globals['_RESOLVEDDROPSNAPSHOTTABLESTMTPROTO']._serialized_start=48461
  _globals['_RESOLVEDDROPSNAPSHOTTABLESTMTPROTO']._serialized_end=48587
  _globals['_RESOLVEDRECURSIVEREFSCANPROTO']._serialized_start=48589
  _globals['_RESOLVEDRECURSIVEREFSCANPROTO']._serialized_end=48664
  _globals['_RESOLVEDRECURSIONDEPTHMODIFIERPROTO']._serialized_start=48667
  _globals['_RESOLVEDRECURSIONDEPTHMODIFIERPROTO']._serialized_end=48924
  _globals['_RESOLVEDRECURSIVESCANPROTO']._serialized_start=48927
  _globals['_RESOLVEDRECURSIVESCANPROTO']._serialized_end=49291
  _globals['_RESOLVEDWITHSCANPROTO']._serialized_start=49294
  _globals['_RESOLVEDWITHSCANPROTO']._serialized_end=49484
  _globals['_RESOLVEDWITHENTRYPROTO']._serialized_start=49487
  _globals['_RESOLVEDWITHENTRYPROTO']._serialized_end=49638
  _globals['_RESOLVEDOPTIONPROTO']._serialized_start=49641
  _globals['_RESOLVEDOPTIONPROTO']._serialized_end=49855
  _globals['_RESOLVEDWINDOWPARTITIONINGPROTO']._serialized_start=49858
  _globals['_RESOLVEDWINDOWPARTITIONINGPROTO']._serialized_end=50105
  _globals['_RESOLVEDWINDOWORDERINGPROTO']._serialized_start=50108
  _globals['_RESOLVEDWINDOWORDERINGPROTO']._serialized_end=50297
  _globals['_RESOLVEDWINDOWFRAMEPROTO']._serialized_start=50300
  _globals['_RESOLVEDWINDOWFRAMEPROTO']._serialized_end=50555
  _globals['_RESOLVEDANALYTICFUNCTIONGROUPPROTO']._serialized_start=50558
  _globals['_RESOLVEDANALYTICFUNCTIONGROUPPROTO']._serialized_end=50839
  _globals['_RESOLVEDWINDOWFRAMEEXPRPROTO']._serialized_start=50842
  _globals['_RESOLVEDWINDOWFRAMEEXPRPROTO']._serialized_end=51046
  _globals['_RESOLVEDDMLVALUEPROTO']._serialized_start=51048
  _globals['_RESOLVEDDMLVALUEPROTO']._serialized_end=51165
  _globals['_RESOLVEDDMLDEFAULTPROTO']._serialized_start=51167
  _globals['_RESOLVEDDMLDEFAULTPROTO']._serialized_end=51236
  _globals['_RESOLVEDASSERTSTMTPROTO']._serialized_start=51239
  _globals['_RESOLVEDASSERTSTMTPROTO']._serialized_end=51385
  _globals['_RESOLVEDASSERTROWSMODIFIEDPROTO']._serialized_start=51387
  _globals['_RESOLVEDASSERTROWSMODIFIEDPROTO']._serialized_end=51513
  _globals['_RESOLVEDONCONFLICTCLAUSEPROTO']._serialized_start=51516
  _globals['_RESOLVEDONCONFLICTCLAUSEPROTO']._serialized_end=51956
  _globals['_RESOLVEDINSERTROWPROTO']._serialized_start=51958
  _globals['_RESOLVEDINSERTROWPROTO']._serialized_end=52082
  _globals['_RESOLVEDINSERTSTMTPROTO']._serialized_start=52085
  _globals['_RESOLVEDINSERTSTMTPROTO']._serialized_end=52954
  _globals['_RESOLVEDDELETESTMTPROTO']._serialized_start=52957
  _globals['_RESOLVEDDELETESTMTPROTO']._serialized_end=53404
  _globals['_RESOLVEDUPDATEITEMPROTO']._serialized_start=53407
  _globals['_RESOLVEDUPDATEITEMPROTO']._serialized_end=53878
  _globals['_RESOLVEDUPDATEITEMELEMENTPROTO']._serialized_start=53881
  _globals['_RESOLVEDUPDATEITEMELEMENTPROTO']._serialized_end=54066
  _globals['_RESOLVEDUPDATESTMTPROTO']._serialized_start=54069
  _globals['_RESOLVEDUPDATESTMTPROTO']._serialized_end=54748
  _globals['_RESOLVEDMERGEWHENPROTO']._serialized_start=54751
  _globals['_RESOLVEDMERGEWHENPROTO']._serialized_end=55173
  _globals['_RESOLVEDMERGESTMTPROTO']._serialized_start=55176
  _globals['_RESOLVEDMERGESTMTPROTO']._serialized_end=55536
  _globals['_RESOLVEDTRUNCATESTMTPROTO']._serialized_start=55539
  _globals['_RESOLVEDTRUNCATESTMTPROTO']._serialized_end=55719
  _globals['_RESOLVEDOBJECTUNITPROTO']._serialized_start=55721
  _globals['_RESOLVEDOBJECTUNITPROTO']._serialized_end=55813
  _globals['_RESOLVEDPRIVILEGEPROTO']._serialized_start=55816
  _globals['_RESOLVEDPRIVILEGEPROTO']._serialized_end=55962
  _globals['_ANYRESOLVEDGRANTORREVOKESTMTPROTO']._serialized_start=55965
  _globals['_ANYRESOLVEDGRANTORREVOKESTMTPROTO']._serialized_end=56148
  _globals['_RESOLVEDGRANTORREVOKESTMTPROTO']._serialized_start=56151
  _globals['_RESOLVEDGRANTORREVOKESTMTPROTO']._serialized_end=56414
  _globals['_RESOLVEDGRANTSTMTPROTO']._serialized_start=56416
  _globals['_RESOLVEDGRANTSTMTPROTO']._serialized_end=56497
  _globals['_RESOLVEDREVOKESTMTPROTO']._serialized_start=56499
  _globals['_RESOLVEDREVOKESTMTPROTO']._serialized_end=56581
  _globals['_ANYRESOLVEDALTEROBJECTSTMTPROTO']._serialized_start=56584
  _globals['_ANYRESOLVEDALTEROBJECTSTMTPROTO']._serialized_end=57999
  _globals['_RESOLVEDALTEROBJECTSTMTPROTO']._serialized_start=58002
  _globals['_RESOLVEDALTEROBJECTSTMTPROTO']._serialized_end=58187
  _globals['_RESOLVEDALTERDATABASESTMTPROTO']._serialized_start=58189
  _globals['_RESOLVEDALTERDATABASESTMTPROTO']._serialized_end=58276
  _globals['_RESOLVEDALTERINDEXSTMTPROTO']._serialized_start=58279
  _globals['_RESOLVEDALTERINDEXSTMTPROTO']._serialized_end=58514
  _globals['_RESOLVEDALTERMATERIALIZEDVIEWSTMTPROTO']._serialized_start=58516
  _globals['_RESOLVEDALTERMATERIALIZEDVIEWSTMTPROTO']._serialized_end=58611
  _globals['_RESOLVEDALTERAPPROXVIEWSTMTPROTO']._serialized_start=58613
  _globals['_RESOLVEDALTERAPPROXVIEWSTMTPROTO']._serialized_end=58702
  _globals['_RESOLVEDALTERSCHEMASTMTPROTO']._serialized_start=58704
  _globals['_RESOLVEDALTERSCHEMASTMTPROTO']._serialized_end=58789
  _globals['_RESOLVEDALTEREXTERNALSCHEMASTMTPROTO']._serialized_start=58791
  _globals['_RESOLVEDALTEREXTERNALSCHEMASTMTPROTO']._serialized_end=58884
  _globals['_RESOLVEDALTERMODELSTMTPROTO']._serialized_start=58886
  _globals['_RESOLVEDALTERMODELSTMTPROTO']._serialized_end=58970
  _globals['_RESOLVEDALTERTABLESTMTPROTO']._serialized_start=58972
  _globals['_RESOLVEDALTERTABLESTMTPROTO']._serialized_end=59056
  _globals['_RESOLVEDALTERVIEWSTMTPROTO']._serialized_start=59058
  _globals['_RESOLVEDALTERVIEWSTMTPROTO']._serialized_end=59141
  _globals['_ANYRESOLVEDALTERACTIONPROTO']._serialized_start=59144
  _globals['_ANYRESOLVEDALTERACTIONPROTO']._serialized_end=61145
  _globals['_RESOLVEDALTERACTIONPROTO']._serialized_start=61147
  _globals['_RESOLVEDALTERACTIONPROTO']._serialized_end=61221
  _globals['_ANYRESOLVEDALTERCOLUMNACTIONPROTO']._serialized_start=61224
  _globals['_ANYRESOLVEDALTERCOLUMNACTIONPROTO']._serialized_end=62041
  _globals['_RESOLVEDALTERCOLUMNACTIONPROTO']._serialized_start=62043
  _globals['_RESOLVEDALTERCOLUMNACTIONPROTO']._serialized_end=62164
  _globals['_RESOLVEDSETOPTIONSACTIONPROTO']._serialized_start=62167
  _globals['_RESOLVEDSETOPTIONSACTIONPROTO']._serialized_end=62300
  _globals['_RESOLVEDALTERSUBENTITYACTIONPROTO']._serialized_start=62303
  _globals['_RESOLVEDALTERSUBENTITYACTIONPROTO']._serialized_end=62506
  _globals['_RESOLVEDADDSUBENTITYACTIONPROTO']._serialized_start=62509
  _globals['_RESOLVEDADDSUBENTITYACTIONPROTO']._serialized_end=62706
  _globals['_RESOLVEDDROPSUBENTITYACTIONPROTO']._serialized_start=62709
  _globals['_RESOLVEDDROPSUBENTITYACTIONPROTO']._serialized_end=62851
  _globals['_RESOLVEDADDCOLUMNACTIONPROTO']._serialized_start=62854
  _globals['_RESOLVEDADDCOLUMNACTIONPROTO']._serialized_end=63028
  _globals['_RESOLVEDADDCOLUMNIDENTIFIERACTIONPROTO']._serialized_start=63031
  _globals['_RESOLVEDADDCOLUMNIDENTIFIERACTIONPROTO']._serialized_end=63214
  _globals['_RESOLVEDREBUILDACTIONPROTO']._serialized_start=63216
  _globals['_RESOLVEDREBUILDACTIONPROTO']._serialized_end=63295
  _globals['_RESOLVEDADDCONSTRAINTACTIONPROTO']._serialized_start=63298
  _globals['_RESOLVEDADDCONSTRAINTACTIONPROTO']._serialized_end=63505
  _globals['_RESOLVEDDROPCONSTRAINTACTIONPROTO']._serialized_start=63507
  _globals['_RESOLVEDDROPCONSTRAINTACTIONPROTO']._serialized_end=63629
  _globals['_RESOLVEDDROPPRIMARYKEYACTIONPROTO']._serialized_start=63631
  _globals['_RESOLVEDDROPPRIMARYKEYACTIONPROTO']._serialized_end=63739
  _globals['_RESOLVEDALTERCOLUMNOPTIONSACTIONPROTO']._serialized_start=63742
  _globals['_RESOLVEDALTERCOLUMNOPTIONSACTIONPROTO']._serialized_end=63889
  _globals['_RESOLVEDALTERCOLUMNDROPNOTNULLACTIONPROTO']._serialized_start=63891
  _globals['_RESOLVEDALTERCOLUMNDROPNOTNULLACTIONPROTO']._serialized_end=63991
  _globals['_RESOLVEDALTERCOLUMNDROPGENERATEDACTIONPROTO']._serialized_start=63993
  _globals['_RESOLVEDALTERCOLUMNDROPGENERATEDACTIONPROTO']._serialized_end=64095
  _globals['_RESOLVEDALTERCOLUMNSETGENERATEDACTIONPROTO']._serialized_start=64098
  _globals['_RESOLVEDALTERCOLUMNSETGENERATEDACTIONPROTO']._serialized_end=64273
  _globals['_RESOLVEDALTERCOLUMNSETDATATYPEACTIONPROTO']._serialized_start=64276
  _globals['_RESOLVEDALTERCOLUMNSETDATATYPEACTIONPROTO']._serialized_end=64551
  _globals['_RESOLVEDALTERCOLUMNSETDEFAULTACTIONPROTO']._serialized_start=64554
  _globals['_RESOLVEDALTERCOLUMNSETDEFAULTACTIONPROTO']._serialized_end=64718
  _globals['_RESOLVEDALTERCOLUMNDROPDEFAULTACTIONPROTO']._serialized_start=64720
  _globals['_RESOLVEDALTERCOLUMNDROPDEFAULTACTIONPROTO']._serialized_end=64820
  _globals['_RESOLVEDDROPCOLUMNACTIONPROTO']._serialized_start=64822
  _globals['_RESOLVEDDROPCOLUMNACTIONPROTO']._serialized_end=64940
  _globals['_RESOLVEDRENAMECOLUMNACTIONPROTO']._serialized_start=64943
  _globals['_RESOLVEDRENAMECOLUMNACTIONPROTO']._serialized_end=65081
  _globals['_RESOLVEDSETASACTIONPROTO']._serialized_start=65084
  _globals['_RESOLVEDSETASACTIONPROTO']._serialized_end=65213
  _globals['_RESOLVEDSETCOLLATECLAUSEPROTO']._serialized_start=65216
  _globals['_RESOLVEDSETCOLLATECLAUSEPROTO']._serialized_end=65353
  _globals['_RESOLVEDALTERTABLESETOPTIONSSTMTPROTO']._serialized_start=65356
  _globals['_RESOLVEDALTERTABLESETOPTIONSSTMTPROTO']._serialized_end=65536
  _globals['_RESOLVEDRENAMESTMTPROTO']._serialized_start=65539
  _globals['_RESOLVEDRENAMESTMTPROTO']._serialized_end=65680
  _globals['_RESOLVEDCREATEPRIVILEGERESTRICTIONSTMTPROTO']._serialized_start=65683
  _globals['_RESOLVEDCREATEPRIVILEGERESTRICTIONSTMTPROTO']._serialized_end=65924
  _globals['_RESOLVEDCREATEROWACCESSPOLICYSTMTPROTO']._serialized_start=65927
  _globals['_RESOLVEDCREATEROWACCESSPOLICYSTMTPROTO']._serialized_end=66333
  _globals['_RESOLVEDDROPPRIVILEGERESTRICTIONSTMTPROTO']._serialized_start=66336
  _globals['_RESOLVEDDROPPRIVILEGERESTRICTIONSTMTPROTO']._serialized_end=66554
  _globals['_RESOLVEDDROPROWACCESSPOLICYSTMTPROTO']._serialized_start=66557
  _globals['_RESOLVEDDROPROWACCESSPOLICYSTMTPROTO']._serialized_end=66727
  _globals['_RESOLVEDDROPINDEXSTMTPROTO']._serialized_start=66730
  _globals['_RESOLVEDDROPINDEXSTMTPROTO']._serialized_end=66935
  _globals['_RESOLVEDGRANTTOACTIONPROTO']._serialized_start=66938
  _globals['_RESOLVEDGRANTTOACTIONPROTO']._serialized_end=67075
  _globals['_RESOLVEDRESTRICTTOACTIONPROTO']._serialized_start=67078
  _globals['_RESOLVEDRESTRICTTOACTIONPROTO']._serialized_end=67216
  _globals['_RESOLVEDADDTORESTRICTEELISTACTIONPROTO']._serialized_start=67219
  _globals['_RESOLVEDADDTORESTRICTEELISTACTIONPROTO']._serialized_end=67392
  _globals['_RESOLVEDREMOVEFROMRESTRICTEELISTACTIONPROTO']._serialized_start=67395
  _globals['_RESOLVEDREMOVEFROMRESTRICTEELISTACTIONPROTO']._serialized_end=67569
  _globals['_RESOLVEDFILTERUSINGACTIONPROTO']._serialized_start=67572
  _globals['_RESOLVEDFILTERUSINGACTIONPROTO']._serialized_end=67728
  _globals['_RESOLVEDREVOKEFROMACTIONPROTO']._serialized_start=67731
  _globals['_RESOLVEDREVOKEFROMACTIONPROTO']._serialized_end=67899
  _globals['_RESOLVEDRENAMETOACTIONPROTO']._serialized_start=67901
  _globals['_RESOLVEDRENAMETOACTIONPROTO']._serialized_end=67999
  _globals['_RESOLVEDALTERPRIVILEGERESTRICTIONSTMTPROTO']._serialized_start=68002
  _globals['_RESOLVEDALTERPRIVILEGERESTRICTIONSTMTPROTO']._serialized_end=68186
  _globals['_RESOLVEDALTERROWACCESSPOLICYSTMTPROTO']._serialized_start=68189
  _globals['_RESOLVEDALTERROWACCESSPOLICYSTMTPROTO']._serialized_end=68350
  _globals['_RESOLVEDALTERALLROWACCESSPOLICIESSTMTPROTO']._serialized_start=68353
  _globals['_RESOLVEDALTERALLROWACCESSPOLICIESSTMTPROTO']._serialized_end=68505
  _globals['_RESOLVEDCREATECONSTANTSTMTPROTO']._serialized_start=68508
  _globals['_RESOLVEDCREATECONSTANTSTMTPROTO']._serialized_end=68641
  _globals['_RESOLVEDCREATEFUNCTIONSTMTPROTO']._serialized_start=68644
  _globals['_RESOLVEDCREATEFUNCTIONSTMTPROTO']._serialized_end=69354
  _globals['_RESOLVEDARGUMENTDEFPROTO']._serialized_start=69357
  _globals['_RESOLVEDARGUMENTDEFPROTO']._serialized_end=69550
  _globals['_RESOLVEDARGUMENTREFPROTO']._serialized_start=69553
  _globals['_RESOLVEDARGUMENTREFPROTO']._serialized_end=69708
  _globals['_RESOLVEDCREATETABLEFUNCTIONSTMTPROTO']._serialized_start=69711
  _globals['_RESOLVEDCREATETABLEFUNCTIONSTMTPROTO']._serialized_end=70210
  _globals['_RESOLVEDRELATIONARGUMENTSCANPROTO']._serialized_start=70212
  _globals['_RESOLVEDRELATIONARGUMENTSCANPROTO']._serialized_end=70329
  _globals['_RESOLVEDARGUMENTLISTPROTO']._serialized_start=70332
  _globals['_RESOLVEDARGUMENTLISTPROTO']._serialized_end=70460
  _globals['_RESOLVEDFUNCTIONSIGNATUREHOLDERPROTO']._serialized_start=70463
  _globals['_RESOLVEDFUNCTIONSIGNATUREHOLDERPROTO']._serialized_end=70601
  _globals['_RESOLVEDDROPFUNCTIONSTMTPROTO']._serialized_start=70604
  _globals['_RESOLVEDDROPFUNCTIONSTMTPROTO']._serialized_end=70846
  _globals['_RESOLVEDDROPTABLEFUNCTIONSTMTPROTO']._serialized_start=70848
  _globals['_RESOLVEDDROPTABLEFUNCTIONSTMTPROTO']._serialized_end=70974
  _globals['_RESOLVEDCALLSTMTPROTO']._serialized_start=70977
  _globals['_RESOLVEDCALLSTMTPROTO']._serialized_end=71202
  _globals['_RESOLVEDIMPORTSTMTPROTO']._serialized_start=71205
  _globals['_RESOLVEDIMPORTSTMTPROTO']._serialized_end=71479
  _globals['_RESOLVEDMODULESTMTPROTO']._serialized_start=71482
  _globals['_RESOLVEDMODULESTMTPROTO']._serialized_end=71626
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERPROTO']._serialized_start=71629
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERPROTO']._serialized_end=71847
  _globals['_RESOLVEDCREATEMATERIALIZEDVIEWSTMTPROTO']._serialized_start=71850
  _globals['_RESOLVEDCREATEMATERIALIZEDVIEWSTMTPROTO']._serialized_end=72114
  _globals['_RESOLVEDCREATEAPPROXVIEWSTMTPROTO']._serialized_start=72116
  _globals['_RESOLVEDCREATEAPPROXVIEWSTMTPROTO']._serialized_end=72205
  _globals['_RESOLVEDCREATEPROCEDURESTMTPROTO']._serialized_start=72208
  _globals['_RESOLVEDCREATEPROCEDURESTMTPROTO']._serialized_end=72616
  _globals['_RESOLVEDEXECUTEIMMEDIATEARGUMENTPROTO']._serialized_start=72619
  _globals['_RESOLVEDEXECUTEIMMEDIATEARGUMENTPROTO']._serialized_end=72771
  _globals['_RESOLVEDEXECUTEIMMEDIATESTMTPROTO']._serialized_start=72774
  _globals['_RESOLVEDEXECUTEIMMEDIATESTMTPROTO']._serialized_end=73009
  _globals['_RESOLVEDASSIGNMENTSTMTPROTO']._serialized_start=73012
  _globals['_RESOLVEDASSIGNMENTSTMTPROTO']._serialized_end=73182
  _globals['_RESOLVEDCREATEENTITYSTMTPROTO']._serialized_start=73185
  _globals['_RESOLVEDCREATEENTITYSTMTPROTO']._serialized_end=73395
  _globals['_RESOLVEDALTERENTITYSTMTPROTO']._serialized_start=73397
  _globals['_RESOLVEDALTERENTITYSTMTPROTO']._serialized_end=73503
  _globals['_RESOLVEDPIVOTCOLUMNPROTO']._serialized_start=73506
  _globals['_RESOLVEDPIVOTCOLUMNPROTO']._serialized_end=73679
  _globals['_RESOLVEDPIVOTSCANPROTO']._serialized_start=73682
  _globals['_RESOLVEDPIVOTSCANPROTO']._serialized_end=74086
  _globals['_RESOLVEDRETURNINGCLAUSEPROTO']._serialized_start=74089
  _globals['_RESOLVEDRETURNINGCLAUSEPROTO']._serialized_end=74347
  _globals['_RESOLVEDUNPIVOTARGPROTO']._serialized_start=74349
  _globals['_RESOLVEDUNPIVOTARGPROTO']._serialized_end=74476
  _globals['_RESOLVEDUNPIVOTSCANPROTO']._serialized_start=74479
  _globals['_RESOLVEDUNPIVOTSCANPROTO']._serialized_end=74918
  _globals['_RESOLVEDMATCHRECOGNIZESCANPROTO']._serialized_start=74921
  _globals['_RESOLVEDMATCHRECOGNIZESCANPROTO']._serialized_end=75685
  _globals['_RESOLVEDMEASUREGROUPPROTO']._serialized_start=75688
  _globals['_RESOLVEDMEASUREGROUPPROTO']._serialized_end=75918
  _globals['_RESOLVEDMATCHRECOGNIZEVARIABLEDEFINITIONPROTO']._serialized_start=75921
  _globals['_RESOLVEDMATCHRECOGNIZEVARIABLEDEFINITIONPROTO']._serialized_end=76080
  _globals['_ANYRESOLVEDMATCHRECOGNIZEPATTERNEXPRPROTO']._serialized_start=76083
  _globals['_ANYRESOLVEDMATCHRECOGNIZEPATTERNEXPRPROTO']._serialized_end=76705
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNEXPRPROTO']._serialized_start=76707
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNEXPRPROTO']._serialized_end=76795
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNEMPTYPROTO']._serialized_start=76797
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNEMPTYPROTO']._serialized_end=76903
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORPROTO']._serialized_start=76906
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORPROTO']._serialized_end=77083
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNVARIABLEREFPROTO']._serialized_start=77085
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNVARIABLEREFPROTO']._serialized_end=77211
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONPROTO']._serialized_start=77214
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONPROTO']._serialized_end=77504
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNQUANTIFICATIONPROTO']._serialized_start=77507
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNQUANTIFICATIONPROTO']._serialized_end=77817
  _globals['_RESOLVEDCLONEDATASTMTPROTO']._serialized_start=77820
  _globals['_RESOLVEDCLONEDATASTMTPROTO']._serialized_end=78003
  _globals['_RESOLVEDTABLEANDCOLUMNINFOPROTO']._serialized_start=78006
  _globals['_RESOLVEDTABLEANDCOLUMNINFOPROTO']._serialized_end=78153
  _globals['_RESOLVEDANALYZESTMTPROTO']._serialized_start=78156
  _globals['_RESOLVEDANALYZESTMTPROTO']._serialized_end=78361
  _globals['_RESOLVEDAUXLOADDATAPARTITIONFILTERPROTO']._serialized_start=78364
  _globals['_RESOLVEDAUXLOADDATAPARTITIONFILTERPROTO']._serialized_end=78522
  _globals['_RESOLVEDAUXLOADDATASTMTPROTO']._serialized_start=78525
  _globals['_RESOLVEDAUXLOADDATASTMTPROTO']._serialized_end=79535
  _globals['_RESOLVEDCREATEPROPERTYGRAPHSTMTPROTO']._serialized_start=79538
  _globals['_RESOLVEDCREATEPROPERTYGRAPHSTMTPROTO']._serialized_end=79958
  _globals['_RESOLVEDGRAPHELEMENTTABLEPROTO']._serialized_start=79961
  _globals['_RESOLVEDGRAPHELEMENTTABLEPROTO']._serialized_end=80580
  _globals['_RESOLVEDGRAPHNODETABLEREFERENCEPROTO']._serialized_start=80583
  _globals['_RESOLVEDGRAPHNODETABLEREFERENCEPROTO']._serialized_end=80826
  _globals['_RESOLVEDGRAPHELEMENTLABELPROTO']._serialized_start=80829
  _globals['_RESOLVEDGRAPHELEMENTLABELPROTO']._serialized_end=81015
  _globals['_RESOLVEDGRAPHPROPERTYDECLARATIONPROTO']._serialized_start=81018
  _globals['_RESOLVEDGRAPHPROPERTYDECLARATIONPROTO']._serialized_end=81153
  _globals['_RESOLVEDGRAPHPROPERTYDEFINITIONPROTO']._serialized_start=81156
  _globals['_RESOLVEDGRAPHPROPERTYDEFINITIONPROTO']._serialized_end=81387
  _globals['_RESOLVEDGRAPHDYNAMICLABELSPECIFICATIONPROTO']._serialized_start=81390
  _globals['_RESOLVEDGRAPHDYNAMICLABELSPECIFICATIONPROTO']._serialized_end=81534
  _globals['_RESOLVEDGRAPHDYNAMICPROPERTIESSPECIFICATIONPROTO']._serialized_start=81537
  _globals['_RESOLVEDGRAPHDYNAMICPROPERTIESSPECIFICATIONPROTO']._serialized_end=81689
  _globals['_ANYRESOLVEDGRAPHSCANBASEPROTO']._serialized_start=81692
  _globals['_ANYRESOLVEDGRAPHSCANBASEPROTO']._serialized_end=81884
  _globals['_RESOLVEDGRAPHSCANBASEPROTO']._serialized_start=81886
  _globals['_RESOLVEDGRAPHSCANBASEPROTO']._serialized_end=81958
  _globals['_RESOLVEDGRAPHREFSCANPROTO']._serialized_start=81960
  _globals['_RESOLVEDGRAPHREFSCANPROTO']._serialized_end=82031
  _globals['_RESOLVEDGRAPHLINEARSCANPROTO']._serialized_start=82034
  _globals['_RESOLVEDGRAPHLINEARSCANPROTO']._serialized_end=82167
  _globals['_RESOLVEDGRAPHTABLESCANPROTO']._serialized_start=82170
  _globals['_RESOLVEDGRAPHTABLESCANPROTO']._serialized_end=82422
  _globals['_RESOLVEDGRAPHCALLSCANPROTO']._serialized_start=82425
  _globals['_RESOLVEDGRAPHCALLSCANPROTO']._serialized_end=82672
  _globals['_RESOLVEDGRAPHSCANPROTO']._serialized_start=82675
  _globals['_RESOLVEDGRAPHSCANPROTO']._serialized_end=82935
  _globals['_RESOLVEDGRAPHPATHPATTERNQUANTIFIERPROTO']._serialized_start=82938
  _globals['_RESOLVEDGRAPHPATHPATTERNQUANTIFIERPROTO']._serialized_end=83131
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXPROTO']._serialized_start=83134
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXPROTO']._serialized_end=83349
  _globals['_ANYRESOLVEDGRAPHPATHSCANBASEPROTO']._serialized_start=83352
  _globals['_ANYRESOLVEDGRAPHPATHSCANBASEPROTO']._serialized_end=83562
  _globals['_RESOLVEDGRAPHPATHSCANBASEPROTO']._serialized_start=83564
  _globals['_RESOLVEDGRAPHPATHSCANBASEPROTO']._serialized_end=83640
  _globals['_ANYRESOLVEDGRAPHELEMENTSCANPROTO']._serialized_start=83643
  _globals['_ANYRESOLVEDGRAPHELEMENTSCANPROTO']._serialized_end=83843
  _globals['_RESOLVEDGRAPHELEMENTSCANPROTO']._serialized_start=83846
  _globals['_RESOLVEDGRAPHELEMENTSCANPROTO']._serialized_end=84118
  _globals['_RESOLVEDGRAPHNODESCANPROTO']._serialized_start=84120
  _globals['_RESOLVEDGRAPHNODESCANPROTO']._serialized_end=84204
  _globals['_RESOLVEDGRAPHEDGESCANPROTO']._serialized_start=84207
  _globals['_RESOLVEDGRAPHEDGESCANPROTO']._serialized_end=84521
  _globals['_RESOLVEDGRAPHGETELEMENTPROPERTYPROTO']._serialized_start=84524
  _globals['_RESOLVEDGRAPHGETELEMENTPROPERTYPROTO']._serialized_end=84766
  _globals['_ANYRESOLVEDGRAPHLABELEXPRPROTO']._serialized_start=84769
  _globals['_ANYRESOLVEDGRAPHLABELEXPRPROTO']._serialized_end=85061
  _globals['_RESOLVEDGRAPHLABELEXPRPROTO']._serialized_start=85063
  _globals['_RESOLVEDGRAPHLABELEXPRPROTO']._serialized_end=85140
  _globals['_RESOLVEDGRAPHLABELNARYEXPRPROTO']._serialized_start=85143
  _globals['_RESOLVEDGRAPHLABELNARYEXPRPROTO']._serialized_end=85366
  _globals['_RESOLVEDGRAPHLABELPROTO']._serialized_start=85369
  _globals['_RESOLVEDGRAPHLABELPROTO']._serialized_end=85550
  _globals['_RESOLVEDGRAPHWILDCARDLABELPROTO']._serialized_start=85552
  _globals['_RESOLVEDGRAPHWILDCARDLABELPROTO']._serialized_end=85639
  _globals['_RESOLVEDGRAPHELEMENTIDENTIFIERPROTO']._serialized_start=85642
  _globals['_RESOLVEDGRAPHELEMENTIDENTIFIERPROTO']._serialized_end=85989
  _globals['_RESOLVEDGRAPHELEMENTPROPERTYPROTO']._serialized_start=85992
  _globals['_RESOLVEDGRAPHELEMENTPROPERTYPROTO']._serialized_end=86184
  _globals['_RESOLVEDGRAPHMAKEELEMENTPROTO']._serialized_start=86187
  _globals['_RESOLVEDGRAPHMAKEELEMENTPROTO']._serialized_end=86565
  _globals['_RESOLVEDARRAYAGGREGATEPROTO']._serialized_start=86568
  _globals['_RESOLVEDARRAYAGGREGATEPROTO']._serialized_end=86887
  _globals['_RESOLVEDGRAPHMAKEARRAYVARIABLEPROTO']._serialized_start=86890
  _globals['_RESOLVEDGRAPHMAKEARRAYVARIABLEPROTO']._serialized_end=87067
  _globals['_RESOLVEDGRAPHPATHMODEPROTO']._serialized_start=87070
  _globals['_RESOLVEDGRAPHPATHMODEPROTO']._serialized_end=87211
  _globals['_RESOLVEDGRAPHPATHCOSTPROTO']._serialized_start=87213
  _globals['_RESOLVEDGRAPHPATHCOSTPROTO']._serialized_end=87333
  _globals['_RESOLVEDGRAPHPATHSCANPROTO']._serialized_start=87336
  _globals['_RESOLVEDGRAPHPATHSCANPROTO']._serialized_end=88059
  _globals['_RESOLVEDGRAPHISLABELEDPREDICATEPROTO']._serialized_start=88062
  _globals['_RESOLVEDGRAPHISLABELEDPREDICATEPROTO']._serialized_end=88266
  _globals['_RESOLVEDUNDROPSTMTPROTO']._serialized_start=88269
  _globals['_RESOLVEDUNDROPSTMTPROTO']._serialized_end=88528
  _globals['_RESOLVEDIDENTITYCOLUMNINFOPROTO']._serialized_start=88531
  _globals['_RESOLVEDIDENTITYCOLUMNINFOPROTO']._serialized_end=88845
  _globals['_RESOLVEDDESCRIBESCANPROTO']._serialized_start=88848
  _globals['_RESOLVEDDESCRIBESCANPROTO']._serialized_end=89031
  _globals['_RESOLVEDSTATICDESCRIBESCANPROTO']._serialized_start=89034
  _globals['_RESOLVEDSTATICDESCRIBESCANPROTO']._serialized_end=89185
  _globals['_RESOLVEDASSERTSCANPROTO']._serialized_start=89188
  _globals['_RESOLVEDASSERTSCANPROTO']._serialized_end=89406
  _globals['_RESOLVEDLOGSCANPROTO']._serialized_start=89409
  _globals['_RESOLVEDLOGSCANPROTO']._serialized_end=89641
  _globals['_RESOLVEDPIPEIFSCANPROTO']._serialized_start=89644
  _globals['_RESOLVEDPIPEIFSCANPROTO']._serialized_end=89843
  _globals['_RESOLVEDPIPEIFCASEPROTO']._serialized_start=89846
  _globals['_RESOLVEDPIPEIFCASEPROTO']._serialized_end=90050
  _globals['_RESOLVEDPIPEFORKSCANPROTO']._serialized_start=90053
  _globals['_RESOLVEDPIPEFORKSCANPROTO']._serialized_end=90252
  _globals['_RESOLVEDPIPETEESCANPROTO']._serialized_start=90255
  _globals['_RESOLVEDPIPETEESCANPROTO']._serialized_end=90453
  _globals['_RESOLVEDPIPEEXPORTDATASCANPROTO']._serialized_start=90456
  _globals['_RESOLVEDPIPEEXPORTDATASCANPROTO']._serialized_end=90597
  _globals['_RESOLVEDPIPECREATETABLESCANPROTO']._serialized_start=90600
  _globals['_RESOLVEDPIPECREATETABLESCANPROTO']._serialized_end=90762
  _globals['_RESOLVEDPIPEINSERTSCANPROTO']._serialized_start=90765
  _globals['_RESOLVEDPIPEINSERTSCANPROTO']._serialized_end=90893
  _globals['_RESOLVEDSUBPIPELINEPROTO']._serialized_start=90895
  _globals['_RESOLVEDSUBPIPELINEPROTO']._serialized_end=91014
  _globals['_RESOLVEDSUBPIPELINEINPUTSCANPROTO']._serialized_start=91016
  _globals['_RESOLVEDSUBPIPELINEINPUTSCANPROTO']._serialized_end=91095
  _globals['_RESOLVEDSUBPIPELINESTMTPROTO']._serialized_start=91098
  _globals['_RESOLVEDSUBPIPELINESTMTPROTO']._serialized_end=91345
  _globals['_RESOLVEDGENERALIZEDQUERYSUBPIPELINEPROTO']._serialized_start=91348
  _globals['_RESOLVEDGENERALIZEDQUERYSUBPIPELINEPROTO']._serialized_end=91553
  _globals['_RESOLVEDBARRIERSCANPROTO']._serialized_start=91555
  _globals['_RESOLVEDBARRIERSCANPROTO']._serialized_end=91676
  _globals['_RESOLVEDCREATECONNECTIONSTMTPROTO']._serialized_start=91679
  _globals['_RESOLVEDCREATECONNECTIONSTMTPROTO']._serialized_end=91820
  _globals['_RESOLVEDALTERCONNECTIONSTMTPROTO']._serialized_start=91822
  _globals['_RESOLVEDALTERCONNECTIONSTMTPROTO']._serialized_end=91911
  _globals['_RESOLVEDLOCKMODEPROTO']._serialized_start=91914
  _globals['_RESOLVEDLOCKMODEPROTO']._serialized_end=92052
  _globals['_RESOLVEDUPDATEFIELDITEMPROTO']._serialized_start=92055
  _globals['_RESOLVEDUPDATEFIELDITEMPROTO']._serialized_end=92306
  _globals['_RESOLVEDUPDATECONSTRUCTORPROTO']._serialized_start=92309
  _globals['_RESOLVEDUPDATECONSTRUCTORPROTO']._serialized_end=92516
  _globals['_RESOLVEDCREATESEQUENCESTMTPROTO']._serialized_start=92519
  _globals['_RESOLVEDCREATESEQUENCESTMTPROTO']._serialized_end=92658
  _globals['_RESOLVEDALTERSEQUENCESTMTPROTO']._serialized_start=92660
  _globals['_RESOLVEDALTERSEQUENCESTMTPROTO']._serialized_end=92747
# @@protoc_insertion_point(module_scope)
